@@ -1,12 +1,40 @@
-#include "ajax.h"
+/* @source ajcall *************************************************************
+**
+** General routines for function callback
+**
+** @author Copyright (c) 1999 Alan Bleasby
+** @version $Revision: 1.28 $
+** @modified $Date: 2011/10/23 20:09:49 $ by $Author: mks $
+** @@
+**
+** This library is free software; you can redistribute it and/or
+** modify it under the terms of the GNU Lesser General Public
+** License as published by the Free Software Foundation; either
+** version 2.1 of the License, or (at your option) any later version.
+**
+** This library is distributed in the hope that it will be useful,
+** but WITHOUT ANY WARRANTY; without even the implied warranty of
+** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+** Lesser General Public License for more details.
+**
+** You should have received a copy of the GNU Lesser General Public
+** License along with this library; if not, write to the Free Software
+** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+** MA  02110-1301,  USA.
+**
+******************************************************************************/
+
+#include "ajlib.h"
+#include "ajcall.h"
+
 #include <stdio.h>
 #include <string.h>
-#include <stdarg.h>
 
 
 
 
-/* ajCall Routines are used to allow access to different library levels.
+/*
+** ajCall Routines are used to allow access to different library levels.
 ** Originally set up for plplot graphics to be optional.
 ** So in ajgraph.c you used to see the register calls which list all the calls
 ** needed by ajacd.c. this is now a higher level library to these are obsolete
@@ -21,59 +49,6 @@ static AjPTable callTable = NULL;
 static AjPTable oldcallTable = NULL;
 static AjPTable oldcallCount = NULL;
 
-static ajint callCmpStr(const void *x, const void *y);
-static unsigned callStrHash(const void *key, unsigned hashsize);
-static void callItemDel(void** key, void** value, void* cl);
-static void callCountDel(void** key, void** value, void* cl);
-
-
-
-
-/* @funcstatic callCmpStr *****************************************************
-**
-** Compare two words.
-**
-** @param [r] x [const void *] First word
-** @param [r] y [const void *] Second word
-** @return [ajint] difference
-** @@
-******************************************************************************/
-
-static ajint callCmpStr(const void *x, const void *y)
-{
-    return strcmp((const char *)x, (const char *)y);
-}
-
-
-
-
-/* @funcstatic callStrHash ****************************************************
-**
-** Create hash value from key.
-**
-** @param [r] key [const void *] key.
-** @param [r] hashsize [unsigned] Hash size
-** @return [unsigned] hash value
-** @@
-******************************************************************************/
-
-static unsigned callStrHash(const void *key, unsigned hashsize)
-{
-    unsigned hashval;
-    const char *s;
-    ajint j;
-
-    ajint i;
-
-    s = (const char *) key;
-    j = strlen(s);
-
-    for(i=0, hashval = 0; i < j; i++, s++)
-	hashval = *s + 31 *hashval;
-
-    return hashval % hashsize;
-}
-
 
 
 
@@ -82,12 +57,14 @@ static unsigned callStrHash(const void *key, unsigned hashsize)
 ** Create new function hash table
 **
 ** @return [AjPTable] Hash table with string keys
+**
+** @release 6.2.0
 ** @@
 ******************************************************************************/
 
 AjPTable ajCallTableNew(void)
 {
-    return ajTableNewFunctionLen(50, callCmpStr,callStrHash);
+    return ajTablecharNew(50);
 }
 
 
@@ -99,21 +76,23 @@ AjPTable ajCallTableNew(void)
 **
 ** @param [w] table [AjPTable] name which is used later.
 ** @param [r] name [const char*] name which is used later.
-** @param [f] func [void*] function to be called on name being called.
+** @param [f] func [void*] Access structure for function to be invoked by name
 ** @return [void]
+**
+** @release 6.2.0
 ** @@
 ******************************************************************************/
 
 void ajCallTableRegister(AjPTable table, const char *name, void *func)
 {
-    void *rec;
+    const void *rec;
     char* keyname = NULL;
  
     if(!table)
       ajFatal("ajCallTableRegister called for undefined table with name '%s'",
 	      name);
 
-    rec = ajTableFetch(table, name);	/* does it exist already */
+    rec = ajTableFetchC(table, name);	/* does it exist already */
 
     if(!rec)
     {
@@ -138,19 +117,21 @@ void ajCallTableRegister(AjPTable table, const char *name, void *func)
 ** @param [r] name [const char*] name which is used later..
 ** @param [f] func [CallFunc] function to be called on name being called.
 ** @return [void]
+**
+** @release 4.0.0
 ** @@
 ******************************************************************************/
 
 void ajCallRegister(const char *name, CallFunc func)
 {
-    void *rec;
+    const void *rec;
     char* keyname = NULL;
 
  
     if(!callTable)
-	callTable = ajTableNewFunctionLen(50, callCmpStr,callStrHash);
+	callTable = ajTablecharNew(50);
 
-    rec = ajTableFetch(callTable, name);	/* does it exist already */
+    rec = ajTableFetchC(callTable, name);	/* does it exist already */
 
     if(!rec)
     {
@@ -164,29 +145,31 @@ void ajCallRegister(const char *name, CallFunc func)
 
 
 
-/* @func ajCallRegisterOld *****************************************************
+/* @func ajCallRegisterOld ****************************************************
 **
 ** Create hash value pair using an obsolete name and function.
 **
 ** @param [r] name [const char*] name which is used later.
 ** @param [f] func [CallFunc] function to be called on name being called.
 ** @return [void]
+**
+** @release 6.2.0
 ** @@
 ******************************************************************************/
 
 void ajCallRegisterOld(const char *name, CallFunc func)
 {
-    void *rec;
+    const void *rec;
     char* keyname = NULL;
     ajuint *i;
  
     if(!oldcallTable)
     {
-	oldcallTable = ajTableNewFunctionLen(50, callCmpStr,callStrHash);
-	oldcallCount = ajTableNewFunctionLen(50, callCmpStr,callStrHash);
+	oldcallTable = ajTablecharNew(50);
+	oldcallCount = ajTablecharNew(50);
     }
     
-    rec = ajTableFetch(oldcallTable, name);	/* does it exist already */
+    rec = ajTableFetchC(oldcallTable, name);	/* does it exist already */
 
     if(!rec)
     {
@@ -211,6 +194,8 @@ void ajCallRegisterOld(const char *name, CallFunc func)
 ** @param [r] name [const char*] name of the function to call.
 ** @param [v] [...] Optional arguments
 ** @return [void*] NULL if function call not found.
+**
+** @release 4.0.0
 ** @@
 ******************************************************************************/
 void* ajCall(const char *name, ...)
@@ -228,8 +213,8 @@ void* ajCall(const char *name, ...)
 	return retval;
     }
 
-    rec = (CallFunc) ajTableFetch(callTable, name);
-    recold = (CallFunc) ajTableFetch(oldcallTable, name);
+    rec = (CallFunc) ajTableFetchmodC(callTable, name);
+    recold = (CallFunc) ajTableFetchmodC(oldcallTable, name);
 
     if(rec)
     {
@@ -239,7 +224,7 @@ void* ajCall(const char *name, ...)
     }
     else if(recold)
     {
-        icount = (ajuint*) ajTableFetch(oldcallCount, name);
+        icount = (ajuint*) ajTableFetchmodC(oldcallCount, name);
         if(!(*icount)++)
             ajWarn("Obsolete graphics call '%s' called via ajCall", name);
 	va_start(args, name);
@@ -260,12 +245,15 @@ void* ajCall(const char *name, ...)
 
 /* @func ajCallTableGetC ******************************************************
 **
-** Returns a named function by its name. If it does not exist then give
-** an error message saying so.
+** Returns an access structure defining the named function. If it does
+** not exist then gives an error message saying so.
 **
 ** @param [r] table [const AjPTable] Function hash table
 ** @param [r] name [const char*] name of the function
-** @return [void*] NULL if function call not found.
+** @return [void*] Access structure defining the named function.
+**                 NULL if not found
+**
+** @release 6.2.0
 ** @@
 ******************************************************************************/
 void* ajCallTableGetC(const AjPTable table, const char *name)
@@ -274,12 +262,12 @@ void* ajCallTableGetC(const AjPTable table, const char *name)
 
     if(!table)
     {
-        ajMessCrash("ajCallTableGet no call table for '%S'",
+        ajMessCrash("ajCallTableGet no call table for '%s'",
 		    name);
 	return NULL;
     }
 
-    rec = ajTableFetch(table, name);
+    rec = ajTableFetchmodC(table, name);
 
     if(!rec)
 	return NULL;
@@ -292,100 +280,34 @@ void* ajCallTableGetC(const AjPTable table, const char *name)
 
 /* @func ajCallTableGetS ******************************************************
 **
-** Returns a named function by its name. If it does not exist then give
-** an error message saying so.
+** Returns an access structure defining the named function. If it does
+** not exist then gives an error message saying so.
 **
 ** @param [r] table [const AjPTable]  Function hash table
 ** @param [r] namestr [const AjPStr] name of the function
-** @return [void*] NULL if function call not found.
+** @return [void*] Access structure defining the named function.
+**                 NULL if not found
+**
+** @release 6.2.0
 ** @@
 ******************************************************************************/
 void* ajCallTableGetS(const AjPTable table, const AjPStr namestr)
 {
-    return ajCallTableGetC(table, MAJSTRGETPTR(namestr));
-}
+    void *rec;
 
+    if(!table)
+    {
+        ajMessCrash("ajCallTableGet no call table for '%S'",
+		    namestr);
+	return NULL;
+    }
 
+    rec = ajTableFetchmodS(table, namestr);
 
+    if(!rec)
+	return NULL;
 
-/* @funcstatic callItemDel ****************************************************
-**
-** Delete an entry in the call table.
-**
-** @param [d] key [void**] Standard argument. Table key (character string)
-** @param [d] value [void**] Standard argument. Table item (function reference)
-** @param [u] cl [void*] Standard argument. Usually NULL.
-** @return [void]
-** @@
-******************************************************************************/
-
-static void callItemDel(void** key, void** value, void* cl)
-{
-    char *p;
-
-    (void) value;
-    (void) cl;
-
-    p = (char*) *key;
-
-    AJFREE(p);
- 
-    *key = NULL;
-    *value = NULL;
-
-    return;
-}
-
-
-
-
-/* @funcstatic callCountDel ***************************************************
-**
-** Delete an entry in the call count table.
-**
-** @param [d] key [void**] Standard argument. Table key (character string)
-** @param [d] value [void**] Standard argument. Table item (unsigned integer)
-** @param [u] cl [void*] Standard argument. Usually NULL.
-** @return [void]
-** @@
-******************************************************************************/
-
-static void callCountDel(void** key, void** value, void* cl)
-{
-    char *p;
-    ajuint *cnt;
-
-    (void) cl;
-
-    p = (char*) *key;
-    cnt = (ajuint*) *value;
-
-    AJFREE(p);
-    AJFREE(cnt);
- 
-    *key = NULL;
-
-    return;
-}
-
-
-
-
-/* @func ajCallTableDel *******************************************************
-**
-** Destructor for a function table
-**
-** @param [d] Ptable [AjPTable*] Table to be freed
-** @return [void]
-******************************************************************************/
-
-void ajCallTableDel(AjPTable* Ptable)
-{
-    if(!*Ptable) return;
-
-    ajTableMapDel(*Ptable, callItemDel, NULL);
-
-    return;
+    return rec;
 }
 
 
@@ -396,18 +318,16 @@ void ajCallTableDel(AjPTable* Ptable)
 ** Cleans up calls register internal memory
 **
 ** @return [void]
+**
+** @release 4.0.0
 ** @@
 ******************************************************************************/
 
 void ajCallExit(void)
 {
-    ajTableMapDel(callTable, callItemDel, NULL);
-    ajTableMapDel(oldcallTable, callItemDel, NULL);
-    ajTableMapDel(oldcallCount, callCountDel, NULL);
-
-    ajTableFree(&callTable);
-    ajTableFree(&oldcallTable);
-    ajTableFree(&oldcallCount);
+    ajTableDel(&callTable);
+    ajTableDel(&oldcallTable);
+    ajTableDel(&oldcallCount);
 
     return;
 }
