@@ -1,28 +1,31 @@
-/******************************************************************************
-** @source AJAX maths functions
+/* @source ajmath *************************************************************
+**
+** AJAX maths functions
 **
 ** @author Copyright (C) 1998 Alan Bleasby
-** @version 1.0
+** @version $Revision: 1.36 $
+** @modified $Date: 2012/12/07 09:56:21 $ by $Author: rice $
 ** @@
 **
 ** This library is free software; you can redistribute it and/or
-** modify it under the terms of the GNU Library General Public
+** modify it under the terms of the GNU Lesser General Public
 ** License as published by the Free Software Foundation; either
-** version 2 of the License, or (at your option) any later version.
+** version 2.1 of the License, or (at your option) any later version.
 **
 ** This library is distributed in the hope that it will be useful,
 ** but WITHOUT ANY WARRANTY; without even the implied warranty of
 ** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-** Library General Public License for more details.
+** Lesser General Public License for more details.
+**
+** You should have received a copy of the GNU Lesser General Public
+** License along with this library; if not, write to the Free Software
+** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+** MA  02110-1301,  USA.
 **
-** You should have received a copy of the GNU Library General Public
-** License along with this library; if not, write to the
-** Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-** Boston, MA  02111-1307, USA.
 ******************************************************************************/
 
-#include "ajax.h"
-
+#include <limits.h>
+#include <ctype.h>
 #include <math.h>
 #include <time.h>
 #include <float.h>
@@ -31,6 +34,11 @@
 #include <sys/time.h>
 #endif
 
+#include "ajmath.h"
+#include "ajmess.h"
+#include "ajstr.h"
+#include "ajnam.h"
+
 
 
 #define AjRandomXmod 1000009711.0
@@ -58,14 +66,22 @@ static void spcrc64calctab(unsigned long long *crctab);
 **
 ** Rounds an integer to be a multiple of a given number.
 **
-** @param [r] i [ajint] Integer to round.
-** @param [r] vround [ajint] Rounding multiple.
+** @param [r] i [ajuint] Integer to round.
+** @param [r] vround [ajuint] Rounding multiple.
 ** @return [ajint] Result.
+**
+** @release 1.0.0
 ******************************************************************************/
 
-ajint ajRound(ajint i, ajint vround)
+ajint ajRound(ajuint i, ajuint vround)
 {
-    return vround * ((ajint)(i+vround-1)/vround);
+    ajuint modi;
+
+    modi = i % vround;
+    if(!modi)
+        return i;
+
+    return i + (vround - modi);
 }
 
 
@@ -76,11 +92,13 @@ ajint ajRound(ajint i, ajint vround)
 ** Rounds a floating point number to have bits free for cumulative addition
 **
 ** @param [r] a [float] Float to round.
-** @param [r] nbits [ajint] Number of bits to free.
+** @param [r] nbits [ajuint] Number of bits to free.
 ** @return [float] Result.
+**
+** @release 6.2.0
 ******************************************************************************/
 
-float ajRoundFloat(float a, ajint nbits)
+float ajRoundFloat(float a, ajuint nbits)
 {
     double w;
     double x;
@@ -117,7 +135,8 @@ float ajRoundFloat(float a, ajint nbits)
     b = ldexp(w, -bitsused);		/* divide by 2**n */
     c = ldexp(b, i);	                /* divide by the orig. power of two */
 
-    /*  ajDebug("\najRoundFloat(%.10e) c: %.10e bitsused: %d\n", a, c, bitsused);
+    /*  ajDebug("\najRoundFloat(%.10e) c: %.10e bitsused: %d\n",
+                a, c, bitsused);
 	ajDebug("       x: %f i: %d y: %f w: %.1f\n", x, i, y, w);*/
 
     return (float) c;
@@ -126,18 +145,6 @@ float ajRoundFloat(float a, ajint nbits)
 
 
 
-/* @obsolete ajRoundF
-** @rename ajRoundFloat
-*/
-
-__deprecated float ajRoundF(float a, ajint nbits)
-{
-    return ajRoundFloat(a, nbits);
-}
-
-
-
-
 /* @func ajCvtRecToPol ********************************************************
 **
 ** Converts Cartesian coordinates to polar
@@ -147,6 +154,8 @@ __deprecated float ajRoundF(float a, ajint nbits)
 ** @param [w] radius [float*] Radius
 ** @param [w] angle [float*] Angle
 ** @return [void]
+**
+** @release 6.2.0
 ******************************************************************************/
 
 void ajCvtRecToPol(float x, float y, float *radius, float *angle)
@@ -160,19 +169,6 @@ void ajCvtRecToPol(float x, float y, float *radius, float *angle)
 
 
 
-/* @obsolete ajRecToPol
-** @rename ajCvtRecToPol
-*/
-
-__deprecated void ajRecToPol(float x, float y, float *radius, float *angle)
-{
-    ajCvtRecToPol(x, y, radius, angle);
-    return;
-}
-
-
-
-
 /* @func ajCvtPolToRec  *******************************************************
 **
 ** Converts polar coordinates to Cartesian
@@ -182,6 +178,8 @@ __deprecated void ajRecToPol(float x, float y, float *radius, float *angle)
 ** @param [w] x [float*] X coordinate
 ** @param [w] y [float*] Y coordinate
 ** @return [void]
+**
+** @release 6.2.0
 ******************************************************************************/
 
 void ajCvtPolToRec(float radius, float angle, float *x, float *y)
@@ -195,19 +193,6 @@ void ajCvtPolToRec(float radius, float angle, float *x, float *y)
 
 
 
-/* @obsolete ajPolToRec
-** @rename ajCvtPolToRec
-*/
-
-__deprecated void ajPolToRec(float radius, float angle, float *x, float *y)
-{
-    ajCvtPolToRec(radius, angle, x, y);
-    return;
-}
-
-
-
-
 
 /* @func ajCvtDegToRad  *******************************************************
 **
@@ -215,6 +200,8 @@ __deprecated void ajPolToRec(float radius, float angle, float *x, float *y)
 **
 ** @param [r] degrees [float] Degrees
 ** @return [float] Radians
+**
+** @release 6.2.0
 ******************************************************************************/
 
 float ajCvtDegToRad(float degrees)
@@ -225,24 +212,14 @@ float ajCvtDegToRad(float degrees)
 
 
 
-/* @obsolete ajDegToRad
-** @rename ajCvtDegToRad
-*/
-
-__deprecated float ajDegToRad(float degrees)
-{
-    return degrees*(float)(AJM_PI/180.0);
-}
-
-
-
-
 /* @func ajCvtRadToDeg   ******************************************************
 **
 ** Converts radians to degrees
 **
 ** @param [r] radians [float] Radians
 ** @return [float] Degrees
+**
+** @release 6.2.0
 ******************************************************************************/
 
 float ajCvtRadToDeg(float radians)
@@ -253,18 +230,6 @@ float ajCvtRadToDeg(float radians)
 
 
 
-/* @obsolete ajRadToDeg
-** @rename ajCvtRadToDeg
-*/
-
-__deprecated float ajRadToDeg(float radians)
-{
-    return radians*(float)(180.0/AJM_PI);
-}
-
-
-
-
 /* @func ajCvtGaussToProb *****************************************************
 **
 ** Returns a probability given a Gaussian distribution
@@ -273,6 +238,8 @@ __deprecated float ajRadToDeg(float radians)
 ** @param [r] sd [float] sd
 ** @param [r] score [float] score
 ** @return [double] probability
+**
+** @release 6.2.0
 ******************************************************************************/
 
 double ajCvtGaussToProb(float mean, float sd, float score)
@@ -284,19 +251,6 @@ double ajCvtGaussToProb(float mean, float sd, float score)
 
 
 
-/* @obsolete ajGaussProb
-** @rename ajCvtGaussToProb
-*/
-
-__deprecated double ajGaussProb(float mean, float sd, float score)
-{
-    return pow(AJM_E,(double)(-0.5*((score-mean)/sd)*((score-mean)/sd)))
-	/ (sd * (float)2.0 * AJM_PI);
-}
-
-
-
-
 /* @func ajMathGmean **********************************************************
 **
 ** Calculate a geometric mean
@@ -304,6 +258,8 @@ __deprecated double ajGaussProb(float mean, float sd, float score)
 ** @param [r] s [const float*] array of values
 ** @param [r] n [ajint] number of values
 ** @return [float] geometric mean
+**
+** @release 6.2.0
 ******************************************************************************/
 
 float ajMathGmean(const float *s, ajint n)
@@ -319,18 +275,6 @@ float ajMathGmean(const float *s, ajint n)
 
 
 
-/* @obsolete ajGeoMean
-** @rename ajMathGmean
-*/
-
-__deprecated float ajGeoMean(const float *s, ajint n)
-{
-    return ajMathGmean(s, n);
-}
-
-
-
-
 /* @func ajMathModulo *********************************************************
 **
 ** Modulo always returning positive number
@@ -338,6 +282,8 @@ __deprecated float ajGeoMean(const float *s, ajint n)
 ** @param [r] a [ajint] value1
 ** @param [r] b [ajint] value2
 ** @return [ajint] value1 modulo value2
+**
+** @release 6.2.0
 ******************************************************************************/
 
 ajint ajMathModulo(ajint a, ajint b)
@@ -355,18 +301,6 @@ ajint ajMathModulo(ajint a, ajint b)
 
 
 
-/* @obsolete ajPosMod
-** @rename ajMathModulo
-*/
-
-__deprecated ajint ajPosMod(ajint a, ajint b)
-{
-    return ajMathModulo(a, b);
-}
-
-
-
-
 /* @func ajRandomSeed *********************************************************
 **
 ** Seed for the ajRandomDouble routine
@@ -383,6 +317,8 @@ __deprecated ajint ajPosMod(ajint a, ajint b)
 **  modified or not.
 **
 ** @return [void]
+**
+** @release 1.0.0
 ******************************************************************************/
 
 void ajRandomSeed(void)
@@ -465,6 +401,8 @@ void ajRandomSeed(void)
 ** Generate a pseudo-random number between 0-32767
 **
 ** @return [ajint] Random number
+**
+** @release 1.0.0
 ******************************************************************************/
 
 ajint ajRandomNumber(void)
@@ -497,6 +435,8 @@ ajint ajRandomNumber(void)
 **  modified or not.
 **
 ** @return [double] Random number
+**
+** @release 6.2.0
 ******************************************************************************/
 
 double ajRandomDouble(void)
@@ -579,18 +519,6 @@ double ajRandomDouble(void)
 
 
 
-/* @obsolete ajRandomNumberD
-** @rename ajRandomDouble
-*/
-
-__deprecated double ajRandomNumberD(void)
-{
-    return ajRandomDouble();
-}
-
-
-
-
 /* @funcstatic spcrc64calctab *************************************************
 **
 ** Initialise the crc table.
@@ -599,6 +527,8 @@ __deprecated double ajRandomNumberD(void)
 ** @param [w] crctab [unsigned long long*] CRC lookup table
 **
 ** @return [void]
+**
+** @release 2.6.0
 ******************************************************************************/
 
 static void spcrc64calctab(unsigned long long *crctab)
@@ -633,6 +563,8 @@ static void spcrc64calctab(unsigned long long *crctab)
 **
 ** @param [r] seq [const AjPStr] Sequence as a string
 ** @return [ajuint] CRC32 checksum.
+**
+** @release 6.2.0
 ** @@
 ******************************************************************************/
 
@@ -666,12 +598,6 @@ ajuint ajMathCrc32(const AjPStr seq)
 }
 
 
-ajuint ajSp32Crc(const AjPStr seq)
-{
-    return ajMathCrc32(seq);
-}
-
-
 
 
 /* @funcstatic spcrc32gen *****************************************************
@@ -679,6 +605,8 @@ ajuint ajSp32Crc(const AjPStr seq)
 ** Generates data for a CRC32 calculation in a static data structure.
 **
 ** @return [void]
+**
+** @release 4.1.0
 ** @@
 ******************************************************************************/
 
@@ -717,6 +645,8 @@ static void spcrc32gen(void)
 ** @param [r] thys [const AjPStr] sequence
 **
 ** @return [unsigned long long] 64-bit CRC
+**
+** @release 6.2.0
 ******************************************************************************/
 
 unsigned long long ajMathCrc64(const AjPStr thys)
@@ -749,11 +679,6 @@ unsigned long long ajMathCrc64(const AjPStr thys)
     return crc;
 }
 
-unsigned long long ajSp64Crc(const AjPStr thys)
-{
-    return ajMathCrc64(thys);
-}
-
 
 
 
@@ -762,25 +687,15 @@ unsigned long long ajSp64Crc(const AjPStr thys)
 ** Converts a string position into a true position. If ipos is negative,
 ** it is counted from the end of the string rather than the beginning.
 **
-** @param [r] len [ajuint] String length.
-** @param [r] ipos [ajint] Position (0 start, negative from the end).
-** @return [ajuint] string position between 0 and (length minus 1).
+** @param [r] len [size_t] String length.
+** @param [r] ipos [ajlong] Position (0 start, negative from the end).
+** @return [size_t] string position between 0 and (length minus 1).
+**
+** @release 6.2.0
 ** @@
 ******************************************************************************/
 
-ajuint ajCvtSposToPos(ajuint len, ajint ipos)
-{
-    return ajCvtSposToPosStart(len, 0, ipos);
-}
-
-
-
-
-/* @obsolete ajMathPos
-** @rename ajCvtSposToPos
-*/
-
-__deprecated ajuint ajMathPos(ajuint len, ajint ipos)
+size_t ajCvtSposToPos(size_t len, ajlong ipos)
 {
     return ajCvtSposToPosStart(len, 0, ipos);
 }
@@ -797,18 +712,20 @@ __deprecated ajuint ajMathPos(ajuint len, ajint ipos)
 ** Usually this is the start position when the end of a range
 ** is being tested.
 **
-** @param [r] len [ajuint] maximum length.
-** @param [r] imin [ajuint] Start position (0 start, no negative values).
-** @param [r] ipos [ajint] Position (0 start, negative from the end).
-** @return [ajuint] string position between 0 and (length minus 1).
+** @param [r] len [size_t] maximum length.
+** @param [r] imin [size_t] Start position (0 start, no negative values).
+** @param [r] ipos [ajlong] Position (0 start, negative from the end).
+** @return [size_t] string position between 0 and (length minus 1).
+**
+** @release 6.2.0
 ** @@
 ******************************************************************************/
 
-ajuint ajCvtSposToPosStart(ajuint len, ajuint imin, ajint ipos)
+size_t ajCvtSposToPosStart(size_t len, size_t imin, ajlong ipos)
 {
-    ajint jpos;
-    ajint jmin = imin;
-    ajint jlen = len;
+    ajlong jpos;
+    ajlong jmin = imin;
+    ajlong jlen = len;
 
     if(ipos < 0)
 	jpos = len + ipos;
@@ -821,19 +738,7 @@ ajuint ajCvtSposToPosStart(ajuint len, ajuint imin, ajint ipos)
     if(jpos < jmin)
 	jpos = imin;
 
-    return (ajuint) jpos;
-}
-
-
-
-
-/* @obsolete ajMathPosI
-** @rename ajCvtSposToPosStart
-*/
-
-__deprecated ajuint ajMathPosI(ajuint len, ajuint imin, ajint ipos)
-{
-    return ajCvtSposToPosStart(len, imin, ipos);
+    return (size_t) jpos;
 }
 
 
@@ -845,6 +750,8 @@ __deprecated ajuint ajMathPosI(ajuint len, ajuint imin, ajint ipos)
 **
 ** @param [r] dnumber [double] Double precision value
 ** @return [ajuint] Number of digits
+**
+** @release 4.1.0
 ** @@
 ******************************************************************************/
 
@@ -871,12 +778,14 @@ ajuint ajNumLengthDouble(double dnumber)
 
 
 
-/* @func ajNumLengthFloat ****************************************************
+/* @func ajNumLengthFloat *****************************************************
 **
 ** Returns the length of a number written as an integer
 **
 ** @param [r] fnumber [float] Single precision value
 ** @return [ajuint] Number of digits
+**
+** @release 4.1.0
 ** @@
 ******************************************************************************/
 
@@ -904,12 +813,14 @@ ajuint ajNumLengthFloat(float fnumber)
 
 
 
-/* @func ajNumLengthInt ****************************************************
+/* @func ajNumLengthInt *******************************************************
 **
 ** Returns the length of a number written as an integer
 **
 ** @param [r] inumber [ajlong] Integer
 ** @return [ajuint] Number of digits
+**
+** @release 4.1.0
 ** @@
 ******************************************************************************/
 
@@ -945,12 +856,14 @@ ajuint ajNumLengthInt(ajlong inumber)
 
 
 
-/* @func ajNumLengthUint ****************************************************
+/* @func ajNumLengthUint ******************************************************
 **
 ** Returns the length of a number written as an integer
 **
 ** @param [r] inumber [ajulong] Unsigned integer
 ** @return [ajuint] Number of digits
+**
+** @release 4.1.0
 ** @@
 ******************************************************************************/
 
@@ -973,3 +886,170 @@ ajuint ajNumLengthUint(ajulong inumber)
 
     return ilen;
 }
+
+
+
+
+#ifdef AJ_COMPILE_DEPRECATED_BOOK
+#endif
+
+
+
+
+#ifdef AJ_COMPILE_DEPRECATED
+/* @obsolete ajRoundF
+** @rename ajRoundFloat
+*/
+
+__deprecated float ajRoundF(float a, ajint nbits)
+{
+    return ajRoundFloat(a, nbits);
+}
+
+
+
+
+/* @obsolete ajRecToPol
+** @rename ajCvtRecToPol
+*/
+
+__deprecated void ajRecToPol(float x, float y, float *radius, float *angle)
+{
+    ajCvtRecToPol(x, y, radius, angle);
+    return;
+}
+
+
+
+
+/* @obsolete ajPolToRec
+** @rename ajCvtPolToRec
+*/
+
+__deprecated void ajPolToRec(float radius, float angle, float *x, float *y)
+{
+    ajCvtPolToRec(radius, angle, x, y);
+    return;
+}
+
+
+
+
+/* @obsolete ajDegToRad
+** @rename ajCvtDegToRad
+*/
+
+__deprecated float ajDegToRad(float degrees)
+{
+    return degrees*(float)(AJM_PI/180.0);
+}
+
+
+
+
+/* @obsolete ajRadToDeg
+** @rename ajCvtRadToDeg
+*/
+
+__deprecated float ajRadToDeg(float radians)
+{
+    return radians*(float)(180.0/AJM_PI);
+}
+
+
+
+
+/* @obsolete ajGaussProb
+** @rename ajCvtGaussToProb
+*/
+
+__deprecated double ajGaussProb(float mean, float sd, float score)
+{
+    return pow(AJM_E,(double)(-0.5*((score-mean)/sd)*((score-mean)/sd)))
+	/ (sd * (float)2.0 * AJM_PI);
+}
+
+
+
+
+/* @obsolete ajGeoMean
+** @rename ajMathGmean
+*/
+
+__deprecated float ajGeoMean(const float *s, ajint n)
+{
+    return ajMathGmean(s, n);
+}
+
+
+
+
+/* @obsolete ajPosMod
+** @rename ajMathModulo
+*/
+
+__deprecated ajint ajPosMod(ajint a, ajint b)
+{
+    return ajMathModulo(a, b);
+}
+
+
+
+
+/* @obsolete ajRandomNumberD
+** @rename ajRandomDouble
+*/
+
+__deprecated double ajRandomNumberD(void)
+{
+    return ajRandomDouble();
+}
+
+
+
+
+/* @obsolete ajSp32Crc
+** @rename ajMathCrc32
+*/
+
+__deprecated ajuint ajSp32Crc(const AjPStr seq)
+{
+    return ajMathCrc32(seq);
+}
+
+
+
+
+/* @obsolete ajMathPos
+** @rename ajCvtSposToPos
+*/
+
+__deprecated ajuint ajMathPos(ajuint len, ajint ipos)
+{
+    return (ajuint) ajCvtSposToPosStart(len, 0, ipos);
+}
+
+
+
+
+/* @obsolete ajMathPosI
+** @rename ajCvtSposToPosStart
+*/
+
+__deprecated ajuint ajMathPosI(ajuint len, ajuint imin, ajint ipos)
+{
+    return ajCvtSposToPosStart(len, imin, ipos);
+}
+
+
+
+
+/* @obsolete ajSp64Crc
+** @rename ajMathCrc64
+*/
+
+__deprecated unsigned long long ajSp64Crc(const AjPStr thys)
+{
+    return ajMathCrc64(thys);
+}
+#endif
