@@ -1,27 +1,37 @@
-/******************************************************************************
-** @source AJAX seqtype functions
+/* @source ajseqtype **********************************************************
+**
+** AJAX seqtype functions
 **
 ** @author Copyright (C) 2002 Peter Rice
-** @version 1.0
+** @version $Revision: 1.84 $
+** @modified 2002-2011 Peter Rice
+** @modified $Date: 2013/06/29 22:30:31 $ by $Author: rice $
 ** @@
 **
 ** This library is free software; you can redistribute it and/or
-** modify it under the terms of the GNU Library General Public
+** modify it under the terms of the GNU Lesser General Public
 ** License as published by the Free Software Foundation; either
-** version 2 of the License, or (at your option) any later version.
+** version 2.1 of the License, or (at your option) any later version.
 **
 ** This library is distributed in the hope that it will be useful,
 ** but WITHOUT ANY WARRANTY; without even the implied warranty of
 ** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-** Library General Public License for more details.
+** Lesser General Public License for more details.
+**
+** You should have received a copy of the GNU Lesser General Public
+** License along with this library; if not, write to the Free Software
+** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+** MA  02110-1301,  USA.
 **
-** You should have received a copy of the GNU Library General Public
-** License along with this library; if not, write to the
-** Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-** Boston, MA  02111-1307, USA.
 ******************************************************************************/
 
-#include "ajax.h"
+#include "ajlib.h"
+
+#include "ajseqtype.h"
+#include "ajseq.h"
+#include "ajfeat.h"
+#include "ajfile.h"
+#include "ajreg.h"
 
 
 
@@ -43,8 +53,9 @@
 **                           ConvertTo equivalent
 ** @attr ConvertTo [const char*] Equivalent for each sequence character in
 **                         ConvertFrom
-** @attr Badchars [(AjPRegexp*)] Test function
-** @attr Goodchars [(AjPStr*)] Test function
+** @attr Badchars [AjPRegexp function] Test function
+** @attr Goodchars [AjPStr function] Test function
+** @attr Filter [char*] Filter for character testing
 ** @attr Desc [const char*] Description for documentation purposes
 ** @@
 ******************************************************************************/
@@ -60,6 +71,7 @@ typedef struct SeqSType
     const char *ConvertTo;
     AjPRegexp (*Badchars) (void);
     AjPStr (*Goodchars) (void);
+    char *Filter;
     const char *Desc;
 } SeqOType;
 
@@ -72,7 +84,7 @@ enum ProtNuc {ISANY=0, ISNUC=1, ISPROT=2};
 
 static char* seqNewGapChars = NULL;
 
-
+static AjPStr seqtypeTmpstr = NULL;
 
 /*
 ** gaps only allowed if it says so
@@ -200,108 +212,134 @@ static SeqOType seqType[] =
     {"any",            AJFALSE, AJTRUE,  ISANY,  0, "?",    "X",
 	 seqTypeCharAny,
 	 seqTypeStrAny,
-	 "any valid sequence"},		/* reset type */
+         NULL,
+         "any valid sequence"},		/* reset type */
     {"gapany",         AJTRUE,  AJTRUE,  ISANY,  0, "?",    "X",
 	 seqTypeCharAnyGap,
 	 seqTypeStrAnyGap,
+         NULL,
 	 "any valid sequence with gaps"}, /* reset type */
     {"dna",            AJFALSE, AJTRUE,  ISNUC,  0, "?XxUu", "NNnTt",
 	 seqTypeCharNuc,
 	 seqTypeStrNuc,
+         NULL,
 	 "DNA sequence"},
     {"puredna",        AJFALSE, AJFALSE, ISNUC,  0, "Uu", "Tt",
 	 seqTypeCharNucPure,
 	 seqTypeStrNucPure,
+         NULL,
 	 "DNA sequence, bases ACGT only"},
     {"gapdna",         AJTRUE,  AJTRUE,  ISNUC,  0, "?XxUu", "NNnTt",
 	 seqTypeCharNucGap,
 	 seqTypeStrNucGap,
+         NULL,
 	 "DNA sequence with gaps"},
     {"gapdnaphylo",    AJTRUE,  AJTRUE,  ISNUC,  0, "Uu",  "Tt",
 	 seqTypeCharNucGapPhylo,
 	 seqTypeStrNucGapPhylo,
+         NULL,
 	 "DNA sequence with gaps and queries"},
     {"rna",            AJFALSE, AJTRUE,  ISNUC,  0, "?XxTt", "NNnUu",
 	 seqTypeCharNuc,
 	 seqTypeStrNuc,
+         NULL,
 	 "RNA sequence"},
     {"purerna",        AJFALSE, AJFALSE, ISNUC,  0, "Tt", "Uu",
 	 seqTypeCharNucPure,
 	 seqTypeStrNucPure,
+         NULL,
 	 "RNA sequence, bases ACGU only"},
     {"gaprna",         AJTRUE,  AJTRUE,  ISNUC,  0, "?XxTt", "NNnUu",
 	 seqTypeCharNucGap,
 	 seqTypeStrNucGap,
+         NULL,
 	 "RNA sequence with gaps"},
     {"gaprnaphylo",     AJTRUE,  AJTRUE,  ISNUC, 0, "Tt",  "Uu",
 	 seqTypeCharNucGapPhylo,
 	 seqTypeStrNucGapPhylo,
+         NULL,
 	 "RNA sequence with gaps and queries"},
     {"nucleotide",     AJFALSE, AJTRUE,  ISNUC,  0, "?Xx",   "NNn",
 	 seqTypeCharNuc,
 	 seqTypeStrNuc,
+         NULL,
 	 "nucleotide sequence"},
     {"purenucleotide", AJFALSE, AJFALSE, ISNUC,  0, NULL,  NULL,
 	 seqTypeCharNucPure,
 	 seqTypeStrNucPure,
+         NULL,
 	 "nucleotide sequence, bases ACGTU only"},
     {"gapnucleotide",  AJTRUE,  AJTRUE,  ISNUC,  0, "?Xx",   "NNn",
 	 seqTypeCharNucGap,
 	 seqTypeStrNucGap,
+         NULL,
 	 "nucleotide sequence with gaps"},
     {"gapnucleotidephylo",  AJTRUE,  AJTRUE,  ISNUC,  0, NULL,  NULL,
 	 seqTypeCharNucGapPhylo,
 	 seqTypeStrNucGapPhylo,
+         NULL,
 	 "nucleotide sequence with gaps and queries"},
     {"gapnucleotidesimple",AJTRUE, AJTRUE , ISNUC,  0,
                      "BbDdHhKkMmRrSsVvWwXxYy?", "NnNnNnNnNnNnNnNnNnNnNnN",
 	 seqTypeCharNucGap,
 	 seqTypeStrNucGap,
+         NULL,
 	 "nucleotide sequence with gaps but only N for ambiguity"},
     {"protein",        AJFALSE, AJTRUE,  ISPROT, 0, "?*",  "XX",
 	 seqTypeCharProt,
 	 seqTypeStrProt,
+         NULL,
 	 "protein sequence"},
     {"pureprotein",    AJFALSE, AJFALSE, ISPROT, 0, NULL,  NULL,
 	 seqTypeCharProtPure,
 	 seqTypeStrProtPure,
+         NULL,
 	 "protein sequence without BZ U X or *"},
     {"stopprotein",    AJFALSE, AJTRUE,  ISPROT, 0, "?",   "X",
 	 seqTypeCharProtStop,
 	 seqTypeStrProtStop,
+         NULL,
 	 "protein sequence with possible stops"},
     {"gapprotein",     AJTRUE,  AJTRUE,  ISPROT, 0, "?*",  "XX",
 	 seqTypeCharProtGap,
 	 seqTypeStrProtGap,
+         NULL,
 	 "protein sequence with gaps"},
     {"gapstopprotein", AJTRUE,  AJTRUE,  ISPROT, 0, "?",  "X",
 	 seqTypeCharProtStopGap,
 	 seqTypeStrProtStopGap,
+         NULL,
 	 "protein sequence with gaps and possible stops"},
     {"gapproteinphylo", AJTRUE,  AJTRUE,  ISPROT, 0, NULL,  NULL,
 	 seqTypeCharProtGapPhylo,
 	 seqTypeStrProtGapPhylo,
+         NULL,
 	 "protein sequence with gaps, stops and queries"},
     {"proteinstandard",AJFALSE, AJTRUE,  ISPROT, 0, "?*UuJjOo", "XXXxXxXx",
 	 seqTypeCharProt,
 	 seqTypeStrProt,
+         NULL,
 	 "protein sequence with no selenocysteine"},
     {"stopproteinstandard",AJFALSE, AJTRUE, ISPROT, 0, "?UuJjOo", "XXxXxXx",
 	 seqTypeCharProtStop,
 	 seqTypeStrProtStop,
+         NULL,
 	 "protein sequence with a possible stop but no selenocysteine"},
     {"gapproteinstandard", AJTRUE,  AJTRUE, ISPROT, 0, "?*UuJjOo", "XXXxXxXx",
 	 seqTypeCharProtGap,
 	 seqTypeStrProtGap,
+         NULL,
 	 "protein sequence with gaps but no selenocysteine"},
     {"gapproteinsimple", AJTRUE,  AJTRUE, ISPROT, 0,
                                               "?*BbZzUuJjOo", "XXXxXxXxXxXx",
 	 seqTypeCharProtGap,
 	 seqTypeStrProtGap,
+         NULL,
 	 "protein sequence with gaps but no selenocysteine"},
     {NULL,             AJFALSE, AJTRUE,  ISANY,  0, NULL,  NULL,
 	 NULL,
 	 NULL,
+         NULL,
 	 NULL}
 };
 
@@ -317,6 +355,8 @@ static SeqOType seqType[] =
 ** @param [u] thys [AjPSeq] Sequence object
 ** @param [r] itype [ajint] Sequence type index
 ** @return [AjBool] ajTrue if compatible.
+**
+** @release 2.8.0
 ** @@
 ******************************************************************************/
 
@@ -369,7 +409,7 @@ static AjBool seqTypeTestI(AjPSeq thys, ajint itype)
 	return ajFalse;
     }
 
-    if(ajStrIsCharsetCaseS(thys->Seq, seqType[itype].Goodchars()))
+    if(ajStrIsCharsetCaseS(thys->Seq, (*seqType[itype].Goodchars)()))
     {
 	if(seqType[itype].ConvertFrom)
 	{
@@ -402,6 +442,8 @@ static AjBool seqTypeTestI(AjPSeq thys, ajint itype)
 ** @param [u] thys [AjPSeq] Sequence object
 ** @param [r] itype [ajint] Sequence type index
 ** @return [AjBool] ajTrue if the type can be fixed
+**
+** @release 2.7.0
 ** @@
 ******************************************************************************/
 
@@ -482,6 +524,8 @@ static AjBool seqTypeFix(AjPSeq thys, ajint itype)
 ** @param [r] itype [ajint] Sequence type index
 ** @param [r] fixchar [char] Character to replace with
 ** @return [AjBool] ajTrue if the type can be fixed
+**
+** @release 2.7.0
 ** @@
 ******************************************************************************/
 
@@ -491,7 +535,7 @@ static AjBool seqTypeFixReg(AjPSeq thys, ajint itype, char fixchar)
     /*ajDebug("Seq old '%S'\n", thys->Seq);*/
 
     return ajStrExchangeSetRestSK(&thys->Seq,
-				  seqType[itype].Goodchars(), fixchar);
+				  (*seqType[itype].Goodchars)(), fixchar);
 }
 
 
@@ -505,6 +549,8 @@ static AjBool seqTypeFixReg(AjPSeq thys, ajint itype, char fixchar)
 ** @param [u] thys [AjPSeq] Sequence object
 ** @param [r] Type [const AjPStr] Sequence type
 ** @return [void]
+**
+** @release 1.0.0
 ** @@
 ******************************************************************************/
 
@@ -527,6 +573,8 @@ static void seqTypeSet(AjPSeq thys, const AjPStr Type)
             ajSeqSetNuc(thys);
             break;
         case '\0':
+        case 'S':
+        case 's':
             break;
         default:
             ajDie("Unknown sequence type '%c'", *cp);
@@ -547,6 +595,8 @@ static void seqTypeSet(AjPSeq thys, const AjPStr Type)
 ** @param [u] pthys [AjPStr*] Sequence string
 ** @param [r] type_name [const AjPStr] Sequence type
 ** @return [AjBool] ajTrue if compatible.
+**
+** @release 2.7.0
 ** @@
 ******************************************************************************/
 
@@ -587,7 +637,7 @@ AjBool ajSeqTypeCheckS(AjPStr* pthys, const AjPStr type_name)
 
     /* no need to test sequence type, we will test every character below */
 
-    if(ajStrIsCharsetCaseS(*pthys, seqType[itype].Goodchars()))
+    if(ajStrIsCharsetCaseS(*pthys, (*seqType[itype].Goodchars)()))
     {
 	if(seqType[itype].ConvertFrom)
 	{
@@ -616,6 +666,8 @@ AjBool ajSeqTypeCheckS(AjPStr* pthys, const AjPStr type_name)
 ** @param [u] thys [AjPSeq] Sequence object
 ** @param [r] seqin [const AjPSeqin] Sequence input object
 ** @return [AjBool] ajTrue if compatible.
+**
+** @release 2.7.0
 ** @@
 ******************************************************************************/
 
@@ -623,7 +675,7 @@ AjBool ajSeqTypeCheckIn(AjPSeq thys, const AjPSeqin seqin)
 {    
     ajint itype = -1;
     AjPStr Type;
-    ajint i;
+    ajlong i;
     
     ajDebug("testing sequence '%s' '%50.50S' type '%S' IsNuc %B IsProt %B\n",
 	    ajSeqGetNameC(thys), thys->Seq,
@@ -637,8 +689,8 @@ AjBool ajSeqTypeCheckIn(AjPSeq thys, const AjPSeqin seqin)
     if(seqin->IsProt)
 	ajSeqSetProt(thys);
     
-    if(seqin->Query && ajStrGetLen(seqin->Query->DbType))
-	seqTypeSet(thys, seqin->Query->DbType);
+    if(seqin->Input->Query && ajStrGetLen(seqin->Input->Query->DbType))
+	seqTypeSet(thys, seqin->Input->Query->DbType);
 
     
     if(!ajStrGetLen(Type))		   /* nothing given - anything goes */
@@ -697,7 +749,10 @@ AjBool ajSeqTypeCheckIn(AjPSeq thys, const AjPSeqin seqin)
 	}
     }
 
-    if(ajStrIsCharsetCaseS(thys->Seq, seqType[itype].Goodchars()))
+    if(!seqType[itype].Filter)
+        seqType[itype].Filter =
+            ajStrGetfilterCase((*seqType[itype].Goodchars)());
+    if(ajStrIsFilter(thys->Seq, seqType[itype].Filter))
     {
 	ajDebug("ajSeqTypeCheckIn: bad characters test passed, convert\n");
 
@@ -722,7 +777,7 @@ AjBool ajSeqTypeCheckIn(AjPSeq thys, const AjPSeqin seqin)
 	return ajTrue;
     }
 
-    i = ajStrFindRestCaseS(thys->Seq, seqType[itype].Goodchars());
+    i = ajStrFindRestCaseS(thys->Seq, (*seqType[itype].Goodchars)());
 
     if(i >= 0)
     {
@@ -745,7 +800,7 @@ AjBool ajSeqTypeCheckIn(AjPSeq thys, const AjPSeqin seqin)
 
 
 
-/* @func ajSeqTypeNucS *****************************************************
+/* @func ajSeqTypeNucS ********************************************************
 **
 ** Checks sequence type for nucleotide without gaps.
 **
@@ -753,6 +808,8 @@ AjBool ajSeqTypeCheckIn(AjPSeq thys, const AjPSeqin seqin)
 **
 ** @param [r] thys [const AjPStr] Sequence string (unchanged at present)
 ** @return [char] invalid character if any.
+**
+** @release 2.7.0
 ** @@
 ******************************************************************************/
 
@@ -772,7 +829,7 @@ char ajSeqTypeNucS(const AjPStr thys)
 
 
 
-/* @func ajSeqTypeDnaS *****************************************************
+/* @func ajSeqTypeDnaS ********************************************************
 **
 ** Checks sequence type for DNA without gaps.
 **
@@ -780,6 +837,8 @@ char ajSeqTypeNucS(const AjPStr thys)
 **
 ** @param [r] thys [const AjPStr] Sequence string (unchanged at present)
 ** @return [char] invalid character if any.
+**
+** @release 2.7.0
 ** @@
 ******************************************************************************/
 
@@ -799,7 +858,7 @@ char ajSeqTypeDnaS(const AjPStr thys)
 
 
 
-/* @func ajSeqTypeRnaS *****************************************************
+/* @func ajSeqTypeRnaS ********************************************************
 **
 ** Checks sequence type for RNA without gaps
 **
@@ -807,6 +866,8 @@ char ajSeqTypeDnaS(const AjPStr thys)
 **
 ** @param [r] thys [const AjPStr] Sequence string (unchanged at present)
 ** @return [char] invalid character if any.
+**
+** @release 2.7.0
 ** @@
 ******************************************************************************/
 
@@ -834,6 +895,8 @@ char ajSeqTypeRnaS(const AjPStr thys)
 **
 ** @param [r] thys [const AjPStr] Sequence string (unchanged at present)
 ** @return [char] invalid character if any.
+**
+** @release 2.7.0
 ** @@
 ******************************************************************************/
 
@@ -861,6 +924,8 @@ char ajSeqTypeGapdnaS(const AjPStr thys)
 **
 ** @param [r] thys [const AjPStr] Sequence string (unchanged at present)
 ** @return [char] invalid character if any.
+**
+** @release 2.7.0
 ** @@
 ******************************************************************************/
 
@@ -888,6 +953,8 @@ char ajSeqTypeGaprnaS(const AjPStr thys)
 **
 ** @param [r] thys [const AjPStr] Sequence string (unchanged at present)
 ** @return [char] invalid character if any.
+**
+** @release 2.7.0
 ** @@
 ******************************************************************************/
 
@@ -909,6 +976,8 @@ char ajSeqTypeGapnucS(const AjPStr thys)
 **
 ** @param [r] thys [const AjPStr] Sequence string (unchanged at present)
 ** @return [char] invalid character if any.
+**
+** @release 2.7.0
 ** @@
 ******************************************************************************/
 
@@ -922,7 +991,7 @@ char ajSeqTypeAnyprotS(const AjPStr thys)
 
 
 
-/* @func ajSeqTypeProtS ****************************************************
+/* @func ajSeqTypeProtS *******************************************************
 **
 ** Checks sequence type for anything that can be in a protein sequence
 **
@@ -930,6 +999,8 @@ char ajSeqTypeAnyprotS(const AjPStr thys)
 **
 ** @param [r] thys [const AjPStr] Sequence string (unchanged at present)
 ** @return [char] invalid character if any.
+**
+** @release 2.7.0
 ** @@
 ******************************************************************************/
 
@@ -951,6 +1022,8 @@ char ajSeqTypeProtS(const AjPStr thys)
 **
 ** @param [r] thys [const AjPStr] Sequence string (unchanged at present)
 ** @return [char] invalid character if any.
+**
+** @release 2.7.0
 ** @@
 ******************************************************************************/
 
@@ -973,6 +1046,8 @@ char ajSeqTypeGapanyS(const AjPStr thys)
 ** @param [r] gapc [char] Standard gap character
 ** @param [r] padc [char] Gap character for ends of sequence
 ** @return [void]
+**
+** @release 1.0.0
 ** @@
 ******************************************************************************/
 
@@ -997,6 +1072,8 @@ void ajSeqGap(AjPSeq thys, char gapc, char padc)
 ** @param [r] ilen [ajint] Sequence length. Expanded if longer than
 **                       current length
 ** @return [void]
+**
+** @release 1.0.0
 ** @@
 ******************************************************************************/
 
@@ -1018,6 +1095,8 @@ void ajSeqGapLen(AjPSeq thys, char gapc, char padc, ajint ilen)
 ** @param [u] seq [AjPStr*] Sequence
 ** @param [r] gapc [char] Standard gap character
 ** @return [void]
+**
+** @release 1.0.0
 ** @@
 ******************************************************************************/
 
@@ -1042,6 +1121,8 @@ void ajSeqGapS(AjPStr* seq, char gapc)
 ** @param [r] ilen [ajuint] Sequence length. Expanded if longer than
 **                       current length
 ** @return [void]
+**
+** @release 1.0.0
 ** @@
 ******************************************************************************/
 
@@ -1071,10 +1152,8 @@ static void seqGapSL(AjPStr* seq, char gapc, char padc, ajuint ilen)
     }
     
     
-    if(ilen)
+    if(ilen >= MAJSTRGETRES(*seq))
 	ajStrSetRes(seq, ilen+1);
-    else
-	ajStrGetuniqueStr(seq);
     
     ajStrExchangeSetCC(seq, seqCharGapTest, seqNewGapChars);
     
@@ -1082,14 +1161,20 @@ static void seqGapSL(AjPStr* seq, char gapc, char padc, ajuint ilen)
     {				/* start and end characters updated */
 	endc = padc;
 
-	/* pad start */
-	for(cp = ajStrGetuniquePtr(seq); strchr(seqCharGapTest, *cp); cp++)
-	    *cp = padc;
+        if(strchr(seqCharGapTest, ajStrGetCharFirst(*seq)))
+        {
+            /* pad start */
+            for(cp = ajStrGetuniquePtr(seq); strchr(seqCharGapTest, *cp); cp++)
+                *cp = padc;
+        }
 
-	cp = ajStrGetuniquePtr(seq);
+        if(strchr(seqCharGapTest, ajStrGetCharLast(*seq)))
+        {
+            cp = ajStrGetuniquePtr(seq);
 
-	for(i=ajStrGetLen(*seq) - 1; i && strchr(seqCharGapTest, cp[i]);  i--)
-	    cp[i] = padc;
+            for(i=ajStrGetLen(*seq) - 1; i && strchr(seqCharGapTest, cp[i]); i--)
+                cp[i] = padc;
+        }
     }
     
     if(ajStrGetLen(*seq) < ilen)	   /* ilen can be zero to skip this */
@@ -1117,6 +1202,8 @@ static void seqGapSL(AjPStr* seq, char gapc, char padc, ajuint ilen)
 **
 ** @param [u] pthys [AjPStr*] Sequence string
 ** @return [AjBool] ajTrue if a stop was removed.
+**
+** @release 2.7.0
 ** @@
 ******************************************************************************/
 
@@ -1143,6 +1230,8 @@ static AjBool seqTypeStopTrimS(AjPStr* pthys)
 ** @param [u] thys [AjPSeq] Sequence object
 ** @return [void]
  ** @category modify [AjPSeq] Sets sequence to be nucleotide
+**
+** @release 1.0.0
 ** @@
 ******************************************************************************/
 
@@ -1174,6 +1263,8 @@ void ajSeqSetNuc(AjPSeq thys)
 ** @param [u] thys [AjPSeq] Sequence object
 ** @return [void]
 ** @category modify [AjPSeq] Sets sequence to be protein
+**
+** @release 1.0.0
 ** @@
 ******************************************************************************/
 
@@ -1199,6 +1290,8 @@ void ajSeqSetProt(AjPSeq thys)
 **
 ** @param [u] thys [AjPSeqset] Sequence set object
 ** @return [void]
+**
+** @release 2.8.0
 ** @@
 ******************************************************************************/
 
@@ -1218,6 +1311,8 @@ void ajSeqsetSetNuc(AjPSeqset thys)
 **
 ** @param [u] thys [AjPSeqset] Sequence set object
 ** @return [void]
+**
+** @release 2.8.0
 ** @@
 ******************************************************************************/
 
@@ -1238,6 +1333,8 @@ void ajSeqsetSetProt(AjPSeqset thys)
 ** @param [u] thys [AjPSeq] Sequence object
 ** @return [void]
 ** @category modify [AjPSeq] Sets the sequence type
+**
+** @release 1.0.0
 ** @@
 ******************************************************************************/
 
@@ -1280,6 +1377,8 @@ void ajSeqType(AjPSeq thys)
 ** @param [u] outf [AjPFile] Output file
 ** @param [r] full [AjBool] Full output
 ** @return [void]
+**
+** @release 2.5.0
 ******************************************************************************/
 
 void ajSeqPrintType(AjPFile outf, AjBool full)
@@ -1293,7 +1392,7 @@ void ajSeqPrintType(AjPFile outf, AjBool full)
 
     (void) full;	    /* make used - no extra detail reported */
 
-    ajFmtPrintF(outf, "\n# Sequence Types\n");
+    ajFmtPrintF(outf, "\n# Sequence types\n");
     ajFmtPrintF(outf, "# Name                 Gap Ambig N/P "
 		"From     To       Description\n");
     ajFmtPrintF(outf, "seqType {\n");
@@ -1347,6 +1446,8 @@ void ajSeqPrintType(AjPFile outf, AjBool full)
 ** @param [u] badchars [AjPRegexp] Regular expression for
 **                                 sequence characters disallowed
 ** @return [char] invalid character if any.
+**
+** @release 2.7.0
 ******************************************************************************/
 
 static char seqTypeTest(const AjPStr thys, AjPRegexp badchars)
@@ -1387,12 +1488,14 @@ static char seqTypeTest(const AjPStr thys, AjPRegexp badchars)
 ** @param [r] goodchars [const AjPStr] String of
 **                                 sequence characters allowed
 ** @return [char] invalid character if any.
+**
+** @release 4.1.0
 ******************************************************************************/
 
 static char seqTypeTestS(const AjPStr thys, const AjPStr goodchars)
 {
     char ret = '\0';
-    ajint i;
+    ajlong i;
 
     if(!ajStrGetLen(thys))
 	return ret;
@@ -1408,7 +1511,8 @@ static char seqTypeTestS(const AjPStr thys, const AjPStr goodchars)
     if (i < 0)
       return ret;
 
-    ret = ajStrGetCharPos(thys, i);
+    ret = ajStrGetCharPos(thys, (size_t) i);
+
     ajDebug("seqTypeTest, Sequence had bad character '%c' (%x) "
 	    "at %d of %d/%d\n",
 	    ret, ret,
@@ -1427,6 +1531,8 @@ static char seqTypeTestS(const AjPStr thys, const AjPStr goodchars)
 ** Returns regular expression to test for type Any
 **
 ** @return [AjPRegexp] valid characters
+**
+** @release 2.7.0
 ******************************************************************************/
 
 static AjPRegexp seqTypeCharAny(void)
@@ -1463,6 +1569,8 @@ static AjPRegexp seqTypeCharAny(void)
 ** Returns regular expression to test for type Any with gaps
 **
 ** @return [AjPRegexp] valid characters
+**
+** @release 2.7.0
 ******************************************************************************/
 
 static AjPRegexp seqTypeCharAnyGap(void)
@@ -1499,6 +1607,8 @@ static AjPRegexp seqTypeCharAnyGap(void)
 ** Returns regular expression to test for nucleotide bases
 **
 ** @return [AjPRegexp] valid characters
+**
+** @release 2.7.0
 ******************************************************************************/
 
 static AjPRegexp seqTypeCharNuc(void)
@@ -1535,6 +1645,8 @@ static AjPRegexp seqTypeCharNuc(void)
 ** Returns regular expression to test for nucleotide bases with gaps
 **
 ** @return [AjPRegexp] valid characters
+**
+** @release 2.7.0
 ******************************************************************************/
 
 static AjPRegexp seqTypeCharNucGap(void)
@@ -1572,6 +1684,8 @@ static AjPRegexp seqTypeCharNucGap(void)
 ** and queries
 **
 ** @return [AjPRegexp] valid characters
+**
+** @release 2.9.0
 ******************************************************************************/
 
 static AjPRegexp seqTypeCharNucGapPhylo(void)
@@ -1609,6 +1723,8 @@ static AjPRegexp seqTypeCharNucGapPhylo(void)
 ** with no ambiguity
 **
 ** @return [AjPRegexp] valid characters
+**
+** @release 2.7.0
 ******************************************************************************/
 
 static AjPRegexp seqTypeCharNucPure(void)
@@ -1645,6 +1761,8 @@ static AjPRegexp seqTypeCharNucPure(void)
 ** Returns regular expression to test for protein residues
 **
 ** @return [AjPRegexp] valid characters
+**
+** @release 2.7.0
 ******************************************************************************/
 
 static AjPRegexp seqTypeCharProt(void)
@@ -1681,6 +1799,8 @@ static AjPRegexp seqTypeCharProt(void)
 ** Returns regular expression to test for protein residues or gaps
 **
 ** @return [AjPRegexp] valid characters
+**
+** @release 2.7.0
 ******************************************************************************/
 
 static AjPRegexp seqTypeCharProtGap(void)
@@ -1718,6 +1838,8 @@ static AjPRegexp seqTypeCharProtGap(void)
 ** stops and queries
 **
 ** @return [AjPRegexp] valid characters
+**
+** @release 2.9.0
 ******************************************************************************/
 
 static AjPRegexp seqTypeCharProtGapPhylo(void)
@@ -1755,6 +1877,8 @@ static AjPRegexp seqTypeCharProtGapPhylo(void)
 ** with no ambiguity
 **
 ** @return [AjPRegexp] valid characters
+**
+** @release 2.7.0
 ******************************************************************************/
 
 static AjPRegexp seqTypeCharProtPure(void)
@@ -1791,6 +1915,8 @@ static AjPRegexp seqTypeCharProtPure(void)
 ** Returns regular expression to test for protein residues or stop codons
 **
 ** @return [AjPRegexp] valid characters
+**
+** @release 2.7.0
 ******************************************************************************/
 
 static AjPRegexp seqTypeCharProtStop(void)
@@ -1828,6 +1954,8 @@ static AjPRegexp seqTypeCharProtStop(void)
 ** or gap characters
 **
 ** @return [AjPRegexp] valid characters
+**
+** @release 4.0.0
 ******************************************************************************/
 
 static AjPRegexp seqTypeCharProtStopGap(void)
@@ -1864,6 +1992,8 @@ static AjPRegexp seqTypeCharProtStopGap(void)
 ** Returns string of valid characters to test for type Any
 **
 ** @return [AjPStr] valid characters
+**
+** @release 4.1.0
 ******************************************************************************/
 
 static AjPStr seqTypeStrAny(void)
@@ -1890,6 +2020,8 @@ static AjPStr seqTypeStrAny(void)
 ** Returns string of valid characters to test for type Anygap
 **
 ** @return [AjPStr] valid characters
+**
+** @release 4.1.0
 ******************************************************************************/
 
 static AjPStr seqTypeStrAnyGap(void)
@@ -1917,6 +2049,8 @@ static AjPStr seqTypeStrAnyGap(void)
 ** Returns string of valid characters to test for type Dnagap
 **
 ** @return [AjPStr] valid characters
+**
+** @release 4.1.0
 ******************************************************************************/
 
 static AjPStr seqTypeStrDnaGap(void)
@@ -1941,6 +2075,8 @@ static AjPStr seqTypeStrDnaGap(void)
 ** Returns string of valid characters to test for type Nuc
 **
 ** @return [AjPStr] valid characters
+**
+** @release 4.1.0
 ******************************************************************************/
 
 static AjPStr seqTypeStrNuc(void)
@@ -1964,6 +2100,8 @@ static AjPStr seqTypeStrNuc(void)
 ** Returns string of valid characters to test for type Nucgap
 **
 ** @return [AjPStr] valid characters
+**
+** @release 4.1.0
 ******************************************************************************/
 
 static AjPStr seqTypeStrNucGap(void)
@@ -1988,6 +2126,8 @@ static AjPStr seqTypeStrNucGap(void)
 ** Returns string of valid characters to test for type Nucgapphylo
 **
 ** @return [AjPStr] valid characters
+**
+** @release 4.1.0
 ******************************************************************************/
 
 static AjPStr seqTypeStrNucGapPhylo(void)
@@ -2013,6 +2153,8 @@ static AjPStr seqTypeStrNucGapPhylo(void)
 ** Returns string of valid characters to test for type Nucpure
 **
 ** @return [AjPStr] valid characters
+**
+** @release 4.1.0
 ******************************************************************************/
 
 static AjPStr seqTypeStrNucPure(void)
@@ -2035,6 +2177,8 @@ static AjPStr seqTypeStrNucPure(void)
 ** Returns string of valid characters to test for type Prot
 **
 ** @return [AjPStr] valid characters
+**
+** @release 4.1.0
 ******************************************************************************/
 
 static AjPStr seqTypeStrProt(void)
@@ -2058,6 +2202,8 @@ static AjPStr seqTypeStrProt(void)
 ** Returns string of valid characters to test for type Protany
 **
 ** @return [AjPStr] valid characters
+**
+** @release 4.1.0
 ******************************************************************************/
 
 static AjPStr seqTypeStrProtAny(void)
@@ -2084,6 +2230,8 @@ static AjPStr seqTypeStrProtAny(void)
 ** Returns string of valid characters to test for type Protgap
 **
 ** @return [AjPStr] valid characters
+**
+** @release 4.1.0
 ******************************************************************************/
 
 static AjPStr seqTypeStrProtGap(void)
@@ -2108,6 +2256,8 @@ static AjPStr seqTypeStrProtGap(void)
 ** Returns string of valid characters to test for type Protgapphylo
 **
 ** @return [AjPStr] valid characters
+**
+** @release 4.1.0
 ******************************************************************************/
 
 static AjPStr seqTypeStrProtGapPhylo(void)
@@ -2134,6 +2284,8 @@ static AjPStr seqTypeStrProtGapPhylo(void)
 ** Returns string of valid characters to test for type Protpure
 **
 ** @return [AjPStr] valid characters
+**
+** @release 4.1.0
 ******************************************************************************/
 
 static AjPStr seqTypeStrProtPure(void)
@@ -2156,6 +2308,8 @@ static AjPStr seqTypeStrProtPure(void)
 ** Returns string of valid characters to test for type Protstop
 **
 ** @return [AjPStr] valid characters
+**
+** @release 4.1.0
 ******************************************************************************/
 
 static AjPStr seqTypeStrProtStop(void)
@@ -2180,6 +2334,8 @@ static AjPStr seqTypeStrProtStop(void)
 ** Returns string of valid characters to test for type Protstopgap
 **
 ** @return [AjPStr] valid characters
+**
+** @release 4.1.0
 ******************************************************************************/
 
 static AjPStr seqTypeStrProtStopGap(void)
@@ -2205,6 +2361,8 @@ static AjPStr seqTypeStrProtStopGap(void)
 ** Returns string of valid characters to test for type Rnagap
 **
 ** @return [AjPStr] valid characters
+**
+** @release 4.1.0
 ******************************************************************************/
 
 static AjPStr seqTypeStrRnaGap(void)
@@ -2231,6 +2389,8 @@ static AjPStr seqTypeStrRnaGap(void)
 ** @param [w] typenum [ajint*] Sequence type index
 ** @return [AjBool] ajTrue if sequence type was found
 **
+**
+** @release 2.7.0
 ******************************************************************************/
 
 static AjBool seqFindType(const AjPStr type_name, ajint* typenum)
@@ -2238,14 +2398,17 @@ static AjBool seqFindType(const AjPStr type_name, ajint* typenum)
     ajint i;
     ajint itype = -1;
 
+    ajStrAssignS(&seqtypeTmpstr, type_name);
+    ajStrFmtLower(&seqtypeTmpstr);
+
     for(i = 0; seqType[i].Name; i++)
-	if(ajStrMatchCaseC(type_name, seqType[i].Name))
+	if(ajStrMatchC(seqtypeTmpstr, seqType[i].Name))
 	{
 	    itype = i;
 	    break;
 	}
 
-    if(itype <0)
+    if(itype < 0)
     {
 	*typenum = i;
 
@@ -2267,6 +2430,8 @@ static AjBool seqFindType(const AjPStr type_name, ajint* typenum)
 ** @param [r] type_name [const AjPStr] Sequence type
 ** @return [AjBool] ajTrue if sequence can be protein
 **
+**
+** @release 2.7.0
 ******************************************************************************/
 
 AjBool ajSeqTypeIsProt(const AjPStr type_name)
@@ -2295,6 +2460,8 @@ AjBool ajSeqTypeIsProt(const AjPStr type_name)
 ** @param [r] type_name [const AjPStr] Sequence type
 ** @return [AjBool] ajTrue if sequence can be nucleotide
 **
+**
+** @release 2.7.0
 ******************************************************************************/
 
 AjBool ajSeqTypeIsNuc(const AjPStr type_name)
@@ -2324,6 +2491,8 @@ AjBool ajSeqTypeIsNuc(const AjPStr type_name)
 ** @param [r] type_name [const AjPStr] Sequence type
 ** @return [AjBool] ajTrue if sequence can be protein or nucleotide
 **
+**
+** @release 2.7.0
 ******************************************************************************/
 
 AjBool ajSeqTypeIsAny(const AjPStr type_name)
@@ -2358,6 +2527,8 @@ AjBool ajSeqTypeIsAny(const AjPStr type_name)
 ** @param [w] gaps [AjBool*] True if gap characters are preserved
 ** @return [AjBool] ajTrue if sequence can be protein or nucleotide
 **
+**
+** @release 4.0.0
 ******************************************************************************/
 
 AjBool ajSeqTypeSummary(const AjPStr type_name, AjPStr* Ptype, AjBool* gaps)
@@ -2394,11 +2565,17 @@ AjBool ajSeqTypeSummary(const AjPStr type_name, AjPStr* Ptype, AjBool* gaps)
 ** Cleans up sequence type processing internal memory
 **
 ** @return [void]
+**
+** @release 4.0.0
 ** @@
 ******************************************************************************/
 
 void ajSeqTypeExit(void)
 {
+    ajuint i;
+
+    ajStrDel(&seqtypeTmpstr);
+
     ajRegFree(&seqtypeRegAny);
     ajRegFree(&seqtypeRegAnyGap);
     ajRegFree(&seqtypeRegDnaGap);
@@ -2429,6 +2606,12 @@ void ajSeqTypeExit(void)
 
     ajCharDel(&seqNewGapChars);
 
+    for(i=0;seqType[i].Name;i++)
+    {
+        if(seqType[i].Filter)
+            AJFREE(seqType[i].Filter);
+    }
+
     return;
 }
 
@@ -2442,6 +2625,8 @@ void ajSeqTypeExit(void)
 **
 ** @return [void]
 **
+**
+** @release 4.1.0
 ******************************************************************************/
 
 void ajSeqTypeUnused(void)
