@@ -1,23 +1,73 @@
-#ifdef __cplusplus
-extern "C"
-{
-#endif
+/* @include ensexternaldatabase ***********************************************
+**
+** Ensembl External Database functions
+**
+** @author Copyright (C) 1999 Ensembl Developers
+** @author Copyright (C) 2006 Michael K. Schuster
+** @version $Revision: 1.20 $
+** @modified 2009 by Alan Bleasby for incorporation into EMBOSS core
+** @modified $Date: 2012/08/05 10:47:13 $ by $Author: mks $
+** @@
+**
+** This library is free software; you can redistribute it and/or
+** modify it under the terms of the GNU Lesser General Public
+** License as published by the Free Software Foundation; either
+** version 2.1 of the License, or (at your option) any later version.
+**
+** This library is distributed in the hope that it will be useful,
+** but WITHOUT ANY WARRANTY; without even the implied warranty of
+** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+** Lesser General Public License for more details.
+**
+** You should have received a copy of the GNU Lesser General Public
+** License along with this library; if not, write to the Free Software
+** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+** MA  02110-1301,  USA.
+**
+******************************************************************************/
 
-#ifndef ensexternaldatabase_h
-#define ensexternaldatabase_h
+#ifndef ENSEXTERNALDATABASE_H
+#define ENSEXTERNALDATABASE_H
+
+/* ========================================================================= */
+/* ============================= include files ============================= */
+/* ========================================================================= */
 
 #include "ensdata.h"
 
+AJ_BEGIN_DECLS
 
 
 
+
+/* ========================================================================= */
+/* =============================== constants =============================== */
+/* ========================================================================= */
+
+
+
+
+/* ========================================================================= */
+/* ============================== public data ============================== */
+/* ========================================================================= */
+
+
+
+
+/* ========================================================================= */
+/* =========================== public functions ============================ */
+/* ========================================================================= */
+
 /*
 ** Prototype definitions
 */
 
 /* Ensembl External Database */
 
-EnsPExternaldatabase ensExternaldatabaseNew(
+EnsPExternaldatabase ensExternaldatabaseNewCpy(
+    const EnsPExternaldatabase edb);
+
+EnsPExternaldatabase ensExternaldatabaseNewIni(
     EnsPExternaldatabaseadaptor edba,
     ajuint identifier,
     AjPStr name,
@@ -26,20 +76,21 @@ EnsPExternaldatabase ensExternaldatabaseNew(
     AjPStr secondaryname,
     AjPStr secondarytable,
     AjPStr description,
-    AjBool primarylinkable,
-    AjBool displaylinkable,
     EnsEExternaldatabaseStatus status,
     EnsEExternaldatabaseType type,
     ajint priority);
 
-EnsPExternaldatabase ensExternaldatabaseNewObj(
-    const EnsPExternaldatabase object);
-
 EnsPExternaldatabase ensExternaldatabaseNewRef(EnsPExternaldatabase edb);
 
 void ensExternaldatabaseDel(EnsPExternaldatabase *Pedb);
 
-const EnsPExternaldatabaseadaptor ensExternaldatabaseGetAdaptor(
+EnsPExternaldatabaseadaptor ensExternaldatabaseGetAdaptor(
+    const EnsPExternaldatabase edb);
+
+AjPStr ensExternaldatabaseGetDescription(
+    const EnsPExternaldatabase edb);
+
+AjPStr ensExternaldatabaseGetDisplayname(
     const EnsPExternaldatabase edb);
 
 ajuint ensExternaldatabaseGetIdentifier(
@@ -48,22 +99,16 @@ ajuint ensExternaldatabaseGetIdentifier(
 AjPStr ensExternaldatabaseGetName(
     const EnsPExternaldatabase edb);
 
+ajint ensExternaldatabaseGetPriority(
+    const EnsPExternaldatabase edb);
+
 AjPStr ensExternaldatabaseGetRelease(
     const EnsPExternaldatabase edb);
 
-AjPStr ensExternaldatabaseGetSecondaryName(
+AjPStr ensExternaldatabaseGetSecondaryname(
     const EnsPExternaldatabase edb);
 
-AjPStr ensExternaldatabaseGetSecondaryTable(
-    const EnsPExternaldatabase edb);
-
-AjPStr ensExternaldatabaseGetDescription(
-    const EnsPExternaldatabase edb);
-
-AjBool ensExternaldatabaseGetPrimaryIdIsLinkable(
-    const EnsPExternaldatabase edb);
-
-AjBool ensExternaldatabaseGetDisplayIdIsLinkable(
+AjPStr ensExternaldatabaseGetSecondarytable(
     const EnsPExternaldatabase edb);
 
 EnsEExternaldatabaseStatus ensExternaldatabaseGetStatus(
@@ -72,57 +117,52 @@ EnsEExternaldatabaseStatus ensExternaldatabaseGetStatus(
 EnsEExternaldatabaseType ensExternaldatabaseGetType(
     const EnsPExternaldatabase edb);
 
-ajint ensExternaldatabaseGetPriority(const EnsPExternaldatabase edb);
-
 AjBool ensExternaldatabaseSetAdaptor(EnsPExternaldatabase edb,
                                      EnsPExternaldatabaseadaptor edba);
 
+AjBool ensExternaldatabaseSetDescription(EnsPExternaldatabase edb,
+                                         AjPStr description);
+
+AjBool ensExternaldatabaseSetDisplayname(EnsPExternaldatabase edb,
+                                         AjPStr displayname);
+
 AjBool ensExternaldatabaseSetIdentifier(EnsPExternaldatabase edb,
                                         ajuint identifier);
 
 AjBool ensExternaldatabaseSetName(EnsPExternaldatabase edb,
                                   AjPStr name);
 
+AjBool ensExternaldatabaseSetPriority(EnsPExternaldatabase edb,
+                                      ajint priority);
+
 AjBool ensExternaldatabaseSetRelease(EnsPExternaldatabase edb,
                                      AjPStr release);
 
-AjBool ensExternaldatabaseSetSecondaryName(EnsPExternaldatabase edb,
+AjBool ensExternaldatabaseSetSecondaryname(EnsPExternaldatabase edb,
                                            AjPStr secondaryname);
 
-AjBool ensExternaldatabaseSetSecondaryTable(EnsPExternaldatabase edb,
+AjBool ensExternaldatabaseSetSecondarytable(EnsPExternaldatabase edb,
                                             AjPStr secondarytable);
 
-AjBool ensExternaldatabaseSetDescription(EnsPExternaldatabase edb,
-                                         AjPStr description);
-
-AjBool ensExternaldatabaseSetPrimaryIdIsLinkable(EnsPExternaldatabase edb,
-                                                 AjBool primarylinkable);
-
-AjBool ensExternaldatabaseSetDisplayIdIsLinkable(EnsPExternaldatabase edb,
-                                                 AjBool displaylinkable);
-
 AjBool ensExternaldatabaseSetStatus(EnsPExternaldatabase edb,
                                     EnsEExternaldatabaseStatus status);
 
 AjBool ensExternaldatabaseSetType(EnsPExternaldatabase edb,
                                   EnsEExternaldatabaseType type);
 
-AjBool ensExternaldatabaseSetPriority(EnsPExternaldatabase edb,
-                                      ajint priority);
-
 AjBool ensExternaldatabaseTrace(const EnsPExternaldatabase edb, ajuint level);
 
+size_t ensExternaldatabaseCalculateMemsize(const EnsPExternaldatabase edb);
+
 EnsEExternaldatabaseStatus ensExternaldatabaseStatusFromStr(
     const AjPStr status);
 
+const char *ensExternaldatabaseStatusToChar(EnsEExternaldatabaseStatus edbs);
+
 EnsEExternaldatabaseType ensExternaldatabaseTypeFromStr(
     const AjPStr type);
 
-const char *ensExternaldatabaseStatusToChar(EnsEExternaldatabaseStatus status);
-
-const char *ensExternaldatabaseTypeToChar(EnsEExternaldatabaseType type);
-
-ajulong ensExternaldatabaseGetMemsize(const EnsPExternaldatabase edb);
+const char *ensExternaldatabaseTypeToChar(EnsEExternaldatabaseType edbt);
 
 /* Ensembl External Database Adaptor */
 
@@ -133,13 +173,13 @@ EnsPExternaldatabaseadaptor ensExternaldatabaseadaptorNew(
     EnsPDatabaseadaptor dba);
 
 void ensExternaldatabaseadaptorDel(
-    EnsPExternaldatabaseadaptor* Pedba);
+    EnsPExternaldatabaseadaptor *Pedba);
 
 EnsPBaseadaptor ensExternaldatabaseadaptorGetBaseadaptor(
-    const EnsPExternaldatabaseadaptor edba);
+    EnsPExternaldatabaseadaptor edba);
 
 EnsPDatabaseadaptor ensExternaldatabaseadaptorGetDatabaseadaptor(
-    const EnsPExternaldatabaseadaptor edba);
+    EnsPExternaldatabaseadaptor edba);
 
 AjBool ensExternaldatabaseadaptorFetchAll(
     EnsPExternaldatabaseadaptor edba,
@@ -153,6 +193,7 @@ AjBool ensExternaldatabaseadaptorFetchByIdentifier(
 AjBool ensExternaldatabaseadaptorFetchByName(
     EnsPExternaldatabaseadaptor edba,
     const AjPStr name,
+    const AjPStr release,
     EnsPExternaldatabase *Pedb);
 
 /*
@@ -162,8 +203,6 @@ AjBool ensExternaldatabaseadaptorFetchByName(
 
 
 
-#endif /* ensexternaldatabase_h */
+AJ_END_DECLS
 
-#ifdef __cplusplus
-}
-#endif
+#endif /* !ENSEXTERNALDATABASE_H */
