@@ -1,17 +1,50 @@
-#ifdef __cplusplus
-extern "C"
-{
-#endif
+/* @include ensprediction *****************************************************
+**
+** Ensembl Prediction functions
+**
+** @author Copyright (C) 1999 Ensembl Developers
+** @author Copyright (C) 2006 Michael K. Schuster
+** @version $Revision: 1.25 $
+** @modified 2009 by Alan Bleasby for incorporation into EMBOSS core
+** @modified $Date: 2012/08/05 11:19:28 $ by $Author: mks $
+** @@
+**
+** This library is free software; you can redistribute it and/or
+** modify it under the terms of the GNU Lesser General Public
+** License as published by the Free Software Foundation; either
+** version 2.1 of the License, or (at your option) any later version.
+**
+** This library is distributed in the hope that it will be useful,
+** but WITHOUT ANY WARRANTY; without even the implied warranty of
+** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+** Lesser General Public License for more details.
+**
+** You should have received a copy of the GNU Lesser General Public
+** License along with this library; if not, write to the Free Software
+** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+** MA  02110-1301,  USA.
+**
+******************************************************************************/
 
-#ifndef ensprediction_h
-#define ensprediction_h
+#ifndef ENSPREDICTION_H
+#define ENSPREDICTION_H
+
+/* ========================================================================= */
+/* ============================= include files ============================= */
+/* ========================================================================= */
 
 #include "ensfeature.h"
 
+AJ_BEGIN_DECLS
 
 
 
-/* EnsPPredictionexonadaptor **************************************************
+
+/* ========================================================================= */
+/* =============================== constants =============================== */
+/* ========================================================================= */
+
+/* @const EnsPPredictionexonadaptor *******************************************
 **
 ** Ensembl Prediction Exon Adaptor
 **
@@ -24,6 +57,23 @@ extern "C"
 
 
 
+/* @const EnsPPredictiontranscriptadaptor *************************************
+**
+** Ensembl Prediction Transcript Adaptor
+**
+** Bio::EnsEMBL::DBSQL::PredictionTranscriptAdaptor
+**
+******************************************************************************/
+
+#define EnsPPredictiontranscriptadaptor EnsPFeatureadaptor
+
+
+
+
+/* ========================================================================= */
+/* ============================== public data ============================== */
+/* ========================================================================= */
+
 /* @data EnsPPredictionexon ***************************************************
 **
 ** Ensembl Prediction Exon.
@@ -41,7 +91,7 @@ extern "C"
 ** @cc 'prediction_exon' SQL table
 ** @attr Score [double] Score
 ** @attr Pvalue [double] P-value
-** @attr StartPhase [ajint] Start phase
+** @attr PhaseStart [ajint] Start phase
 ** @attr Padding [char[4]] Padding to alignment boundary
 ** @attr SequenceCache [AjPStr] Sequence cache
 ** @@
@@ -55,7 +105,7 @@ typedef struct EnsSPredictionexon
     EnsPFeature Feature;
     double Score;
     double Pvalue;
-    ajint StartPhase;
+    ajint PhaseStart;
     char Padding[4];
     AjPStr SequenceCache;
 } EnsOPredictionexon;
@@ -65,19 +115,6 @@ typedef struct EnsSPredictionexon
 
 
 
-/* EnsPPredictiontranscriptadaptor ********************************************
-**
-** Ensembl Prediction Transcript Adaptor
-**
-** Bio::EnsEMBL::DBSQL::PredictionTranscriptAdaptor
-**
-******************************************************************************/
-
-#define EnsPPredictiontranscriptadaptor EnsPFeatureadaptor
-
-
-
-
 /* @data EnsPPredictiontranscript *********************************************
 **
 ** Ensembl Prediction Transcript.
@@ -93,8 +130,8 @@ typedef struct EnsSPredictionexon
 ** @cc Bio::EnsEMBL::Feature
 ** @attr Feature [EnsPFeature] Ensembl Feature
 ** @cc Bio::EnsEMBL::PredictionTranscript
-** @attr DisplayLabel [AjPStr] Display label
-** @attr Predictionexons [AjPList] AJAX List of Ensembl Prediction Exons
+** @attr Displaylabel [AjPStr] Display label
+** @attr Predictionexons [AjPList] AJAX List of Ensembl Prediction Exon objects
 ** @@
 ******************************************************************************/
 
@@ -104,7 +141,7 @@ typedef struct EnsSPredictiontranscript
     ajuint Identifier;
     EnsPPredictiontranscriptadaptor Adaptor;
     EnsPFeature Feature;
-    AjPStr DisplayLabel;
+    AjPStr Displaylabel;
     AjPList Predictionexons;
 } EnsOPredictiontranscript;
 
@@ -113,78 +150,90 @@ typedef struct EnsSPredictiontranscript
 
 
 
+/* ========================================================================= */
+/* =========================== public functions ============================ */
+/* ========================================================================= */
+
 /*
 ** Prototype definitions
 */
 
 /* Ensembl Prediction Exon */
 
-EnsPPredictionexon ensPredictionexonNew(EnsPPredictionexonadaptor pea,
-                                        ajuint identifier,
-                                        EnsPFeature feature,
-                                        ajint sphase,
-                                        double score,
-                                        double pvalue);
+EnsPPredictionexon ensPredictionexonNewCpy(const EnsPPredictionexon pe);
 
-EnsPPredictionexon ensPredictionexonNewObj(const EnsPPredictionexon object);
+EnsPPredictionexon ensPredictionexonNewIni(EnsPPredictionexonadaptor pea,
+                                           ajuint identifier,
+                                           EnsPFeature feature,
+                                           ajint sphase,
+                                           double score,
+                                           double pvalue);
 
 EnsPPredictionexon ensPredictionexonNewRef(EnsPPredictionexon pe);
 
-void ensPredictionexonDel(EnsPPredictionexon* Ppe);
+void ensPredictionexonDel(EnsPPredictionexon *Ppe);
 
 EnsPPredictionexonadaptor ensPredictionexonGetAdaptor(
     const EnsPPredictionexon pe);
 
-ajuint ensPredictionexonGetIdentifier(const EnsPPredictionexon pe);
-
 EnsPFeature ensPredictionexonGetFeature(const EnsPPredictionexon pe);
 
-ajint ensPredictionexonGetStartPhase(const EnsPPredictionexon pe);
+ajuint ensPredictionexonGetIdentifier(const EnsPPredictionexon pe);
 
-double ensPredictionexonGetScore(const EnsPPredictionexon pe);
+ajint ensPredictionexonGetPhaseStart(const EnsPPredictionexon pe);
 
 double ensPredictionexonGetPvalue(const EnsPPredictionexon pe);
 
+double ensPredictionexonGetScore(const EnsPPredictionexon pe);
+
 AjBool ensPredictionexonSetAdaptor(EnsPPredictionexon pe,
                                    EnsPPredictionexonadaptor pea);
 
-AjBool ensPredictionexonSetIdentifier(EnsPPredictionexon pe,
-                                      ajuint identifier);
-
 AjBool ensPredictionexonSetFeature(EnsPPredictionexon pe,
                                    EnsPFeature feature);
 
-AjBool ensPredictionexonSetStartPhase(EnsPPredictionexon pe,
-                                      ajint sphase);
+AjBool ensPredictionexonSetIdentifier(EnsPPredictionexon pe,
+                                      ajuint identifier);
 
-AjBool ensPredictionexonSetScore(EnsPPredictionexon pe,
-                                 double score);
+AjBool ensPredictionexonSetPhaseStart(EnsPPredictionexon pe,
+                                      ajint sphase);
 
 AjBool ensPredictionexonSetPvalue(EnsPPredictionexon pe,
                                   double pvalue);
 
+AjBool ensPredictionexonSetScore(EnsPPredictionexon pe,
+                                 double score);
+
 AjBool ensPredictionexonTrace(const EnsPPredictionexon pe, ajuint level);
 
-ajint ensPredictionexonGetEndPhase(const EnsPPredictionexon pe);
+ajint ensPredictionexonGetPhaseEnd(const EnsPPredictionexon pe);
 
-ajulong ensPredictionexonGetMemsize(const EnsPPredictionexon pe);
+size_t ensPredictionexonCalculateMemsize(const EnsPPredictionexon pe);
+
+EnsPPredictionexon ensPredictionexonTransfer(EnsPPredictionexon pe,
+                                             EnsPSlice slice);
 
 EnsPPredictionexon ensPredictionexonTransform(EnsPPredictionexon pe,
                                               const AjPStr csname,
                                               const AjPStr csversion);
 
-EnsPPredictionexon ensPredictionexonTransfer(EnsPPredictionexon pe,
-                                             EnsPSlice slice);
+AjBool ensPredictionexonFetchSequenceSeq(EnsPPredictionexon pe,
+                                         AjPSeq *Psequence);
 
 AjBool ensPredictionexonFetchSequenceStr(EnsPPredictionexon pe,
                                          AjPStr *Psequence);
 
-AjBool ensPredictionexonFetchSequenceSeq(EnsPPredictionexon pe,
-                                         AjPSeq* Psequence);
+/* AJAX List of Ensembl Prediction Exon objects */
 
-AjBool ensPredictionexonSortByStartAscending(AjPList pes);
+AjBool ensListPredictionexonSortEndAscending(AjPList pes);
 
-AjBool ensPredictionexonSortByStartDescending(AjPList pes);
+AjBool ensListPredictionexonSortEndDescending(AjPList pes);
+
+AjBool ensListPredictionexonSortIdentifierAscending(AjPList pes);
+
+AjBool ensListPredictionexonSortStartAscending(AjPList pes);
+
+AjBool ensListPredictionexonSortStartDescending(AjPList pes);
 
 /* Ensembl Prediction Exon Adaptor */
 
@@ -196,22 +245,36 @@ EnsPPredictionexonadaptor ensPredictionexonadaptorNew(
 
 void ensPredictionexonadaptorDel(EnsPPredictionexonadaptor *Ppea);
 
-AjBool ensPredictionexonadaptorFetchAllByPredictiontranscript(
+EnsPBaseadaptor ensPredictionexonadaptorGetBaseadaptor(
+    EnsPPredictionexonadaptor pea);
+
+EnsPDatabaseadaptor ensPredictionexonadaptorGetDatabaseadaptor(
+    EnsPPredictionexonadaptor pea);
+
+EnsPFeatureadaptor ensPredictionexonadaptorGetFeatureadaptor(
+    EnsPPredictionexonadaptor pea);
+
+AjBool ensPredictionexonadaptorFetchAllbyPredictiontranscript(
     EnsPPredictionexonadaptor pea,
     const EnsPPredictiontranscript pt,
     AjPList pes);
 
+AjBool ensPredictionexonadaptorFetchByIdentifier(
+    EnsPPredictionexonadaptor pea,
+    ajuint identifier,
+    EnsPPredictionexon *Ppe);
+
 /* Ensembl Prediction Transcript */
 
-EnsPPredictiontranscript ensPredictiontranscriptNew(
+EnsPPredictiontranscript ensPredictiontranscriptNewCpy(
+    const EnsPPredictiontranscript pt);
+
+EnsPPredictiontranscript ensPredictiontranscriptNewIni(
     EnsPPredictiontranscriptadaptor pta,
     ajuint identifier,
     EnsPFeature feature,
     AjPStr label);
 
-EnsPPredictiontranscript ensPredictiontranscriptNewObj(
-    const EnsPPredictiontranscript object);
-
 EnsPPredictiontranscript ensPredictiontranscriptNewRef(
     EnsPPredictiontranscript pt);
 
@@ -221,72 +284,89 @@ void ensPredictiontranscriptDel(
 EnsPPredictiontranscriptadaptor ensPredictiontranscriptGetAdaptor(
     const EnsPPredictiontranscript pt);
 
-ajuint ensPredictiontranscriptGetIdentifier(
+AjPStr ensPredictiontranscriptGetDisplaylabel(
     const EnsPPredictiontranscript pt);
 
 EnsPFeature ensPredictiontranscriptGetFeature(
     const EnsPPredictiontranscript pt);
 
-AjPStr ensPredictiontranscriptGetDisplayLabel(
+ajuint ensPredictiontranscriptGetIdentifier(
     const EnsPPredictiontranscript pt);
 
+const AjPList ensPredictiontranscriptLoadPredictionexons(
+    EnsPPredictiontranscript pt);
+
 AjBool ensPredictiontranscriptSetAdaptor(
     EnsPPredictiontranscript pt,
     EnsPPredictiontranscriptadaptor pta);
 
-AjBool ensPredictiontranscriptSetIdentifier(
+AjBool ensPredictiontranscriptSetDisplaylabel(
     EnsPPredictiontranscript pt,
-    ajuint identifier);
+    AjPStr label);
 
 AjBool ensPredictiontranscriptSetFeature(
     EnsPPredictiontranscript pt,
     EnsPFeature feature);
 
-AjBool ensPredictiontranscriptSetDisplayLabel(
+AjBool ensPredictiontranscriptSetIdentifier(
     EnsPPredictiontranscript pt,
-    AjPStr label);
+    ajuint identifier);
 
 AjBool ensPredictiontranscriptTrace(
     const EnsPPredictiontranscript pt,
     ajuint level);
 
-ajulong ensPredictiontranscriptGetMemsize(
+size_t ensPredictiontranscriptCalculateMemsize(
     const EnsPPredictiontranscript pt);
 
-const AjPList ensPredictiontranscriptGetExons(
+ajint ensPredictiontranscriptCalculateSliceCodingEnd(
+    const EnsPPredictiontranscript pt);
+
+ajint ensPredictiontranscriptCalculateSliceCodingStart(
+    const EnsPPredictiontranscript pt);
+
+ajuint ensPredictiontranscriptCalculateTranscriptCodingEnd(
     EnsPPredictiontranscript pt);
 
-ajuint ensPredictiontranscriptGetTranscriptCodingStart(
+ajuint ensPredictiontranscriptCalculateTranscriptCodingStart(
     const EnsPPredictiontranscript pt);
 
-ajuint ensPredictiontranscriptGetTranscriptCodingEnd(
-    EnsPPredictiontranscript pt);
-
-ajuint ensPredictiontranscriptGetSliceCodingStart(
-    const EnsPPredictiontranscript pt);
-
-ajuint ensPredictiontranscriptGetSliceCodingEnd(
-    const EnsPPredictiontranscript pt);
-
-AjBool ensPredictiontranscriptFetchSequenceStr(
-    EnsPPredictiontranscript pt,
-    AjPStr *Psequence);
-
-AjBool ensPredictiontranscriptFetchSequenceSeq(
+AjBool ensPredictiontranscriptFetchSequenceTranscriptSeq(
     EnsPPredictiontranscript pt,
     AjPSeq *Psequence);
 
-AjBool ensPredictiontranscriptFetchTranslationSequenceStr(
+AjBool ensPredictiontranscriptFetchSequenceTranscriptStr(
     EnsPPredictiontranscript pt,
     AjPStr *Psequence);
 
-AjBool ensPredictiontranscriptFetchTranslationSequenceSeq(
+AjBool ensPredictiontranscriptFetchSequenceTranslationSeq(
     EnsPPredictiontranscript pt,
     AjPSeq *Psequence);
 
-AjBool ensPredictiontranscriptSortByStartAscending(AjPList pts);
+AjBool ensPredictiontranscriptFetchSequenceTranslationStr(
+    EnsPPredictiontranscript pt,
+    AjPStr *Psequence);
 
-AjBool ensPredictiontranscriptSortByStartDescending(AjPList pts);
+EnsPPredictiontranscript ensPredictiontranscriptTransfer(
+    EnsPPredictiontranscript pt,
+    EnsPSlice slice);
+
+EnsPPredictiontranscript ensPredictiontranscriptTransform(
+    EnsPPredictiontranscript pt,
+    const AjPStr csname,
+    const AjPStr csversion);
+
+/* AJAX List of Ensembl Prediction Transcript objects */
+
+AjBool ensListPredictiontranscriptSortEndAscending(AjPList pts);
+
+AjBool ensListPredictiontranscriptSortEndDescending(AjPList pts);
+
+AjBool ensListPredictiontranscriptSortIdentifierAscending(AjPList pts);
+
+AjBool ensListPredictiontranscriptSortStartAscending(AjPList pts);
+
+AjBool ensListPredictiontranscriptSortStartDescending(AjPList pts);
 
 /* Ensembl Prediction Transcript Adaptor */
 
@@ -299,12 +379,21 @@ EnsPPredictiontranscriptadaptor ensPredictiontranscriptadaptorNew(
 void ensPredictiontranscriptadaptorDel(
     EnsPPredictiontranscriptadaptor *Ppta);
 
+EnsPBaseadaptor ensPredictiontranscriptadaptorGetBaseadaptor(
+    EnsPPredictiontranscriptadaptor pta);
+
+EnsPDatabaseadaptor ensPredictiontranscriptadaptorGetDatabaseadaptor(
+    EnsPPredictiontranscriptadaptor pta);
+
+EnsPFeatureadaptor ensPredictiontranscriptadaptorGetFeatureadaptor(
+    EnsPPredictiontranscriptadaptor pta);
+
 AjBool ensPredictiontranscriptadaptorFetchByIdentifier(
     EnsPPredictiontranscriptadaptor pta,
     ajuint identifier,
     EnsPPredictiontranscript *Ppt);
 
-AjBool ensPredictiontranscriptadaptorFetchByStableIdentifier(
+AjBool ensPredictiontranscriptadaptorFetchByStableidentifier(
     EnsPPredictiontranscriptadaptor pta,
     const AjPStr stableid,
     EnsPPredictiontranscript *Ppt);
@@ -316,8 +405,6 @@ AjBool ensPredictiontranscriptadaptorFetchByStableIdentifier(
 
 
 
-#endif /* ensprediction_h */
+AJ_END_DECLS
 
-#ifdef __cplusplus
-}
-#endif
+#endif /* !ENSPREDICTION_H */
