@@ -124,14 +124,14 @@ static void maskfeat_FeatSeqMask(AjPSeq seq, const AjPStr type,
 
     /* For all features... */
 
-    if(feat && ajFeattableSize(feat))
+    if(feat && ajFeattableGetSize(feat))
     {
 	iter = ajListIterNewread(feat->Features) ;
 	while(!ajListIterDone(iter))
 	{
 	    gf = ajListIterGet(iter) ;
 	    tokens = ajStrTokenNewC(type, whiteSpace);
-	    while(ajStrTokenNextParse( &tokens, &key))
+	    while(ajStrTokenNextParse(tokens, &key))
 		if(ajStrMatchWildS(ajFeatGetType(gf), key))
 		{
 		    if(lower)
