@@ -114,8 +114,8 @@ int main(int argc, char **argv)
     ajint count;
     ajint k;
     ajint kmax;
-    float defheight;
-    float currentscale;
+    float defheight = 0.0;
+    float currentscale = 0.0;
     AjPStr shade = NULL;
     AjPFloat pair  = NULL;
     AjPGraph graph = NULL;
@@ -183,6 +183,8 @@ int main(int argc, char **argv)
     float part = 0.0;
     const char *cptr;
     ajint resbreak;
+    ajint blocksperline;
+    float ratio;
     float fplural;
     float ystart;
     float xmin;
@@ -206,7 +208,8 @@ int main(int argc, char **argv)
 
     seqset   = ajAcdGetSeqset("sequences");
     numres   = ajAcdGetInt("residuesperline");
-    resbreak = ajAcdGetInt("resbreak");
+    blocksperline = ajAcdGetInt("blocksperline");
+    resbreak = (numres+blocksperline-1)/blocksperline;
 
     ajSeqsetFill(seqset);	/* Pads sequence set with gap characters */
     numseq = ajSeqsetGetSize(seqset);
@@ -217,7 +220,7 @@ int main(int argc, char **argv)
     shade             = ajAcdGetString("shade");
     pair              = ajAcdGetArray("pair");
     identity          = ajAcdGetInt("identity");
-    boxit             = ajAcdGetBoolean("box");
+    boxit             = ajAcdGetBoolean("doboxes");
 
     ajtime = ajTimeNewTodayFmt("daytime");
 
@@ -251,13 +254,15 @@ int main(int argc, char **argv)
     shownames   = ajAcdGetBoolean("name");
     shownumbers = ajAcdGetBoolean("number");
     charlen     = ajAcdGetInt("maxnamelen");
-    fplural     = ajAcdGetFloat("plurality");
+    ratio       = ajAcdGetFloat("ratio");
     portrait    = ajAcdGetBoolean("portrait");
     collision   = ajAcdGetBoolean("collision");
     listoptions = ajAcdGetBoolean("listoptions");
     altstr = ajAcdGetListSingle("alternative");
     cmpmatrix   = ajAcdGetMatrix("matrixfile");
 
+    fplural     = ratio * ajSeqsetGetTotweight(seqset);
+
     ajStrToInt(altstr, &alternative);
 
     matrix = ajMatrixGetMatrix(cmpmatrix);
@@ -434,24 +439,28 @@ int main(int argc, char **argv)
 
     ajGraphicsGetCharsize(&defheight,&currentscale);
 
-    ajGraphicsSetCharscale(((float)ixlen/((float)(numres+charlen)*
-                                          (currentscale+(float)1.0)))/
+    ajGraphicsSetCharscale(((float)ixlen/((float)(numres+charlen+1)*
+                                          (currentscale * (float) 1.5)))/
                                            currentscale);
 
+/*    ajGraphicsSetCharscale(((float)ixlen/((float)(numres+charlen)*
+                                          (currentscale+(float)1.0)))/
+                                          currentscale); */
+
     ajGraphicsGetCharsize(&defheight,&currentscale);
 
     yincr = (currentscale + (float)3.0)*(float)0.3;
 
 /*
-** If we have titles (now the standard graph title and subtitle)
-** leave 5 rows of space for them
+** If we have titles (now the standard graph title and subtitle and footer)
+** leave 7 rows of space for them
 */
-    y=ystart-(float)6.0;
+    y=ystart-(float)7.0;
 
     if(ajStrGetLen(options))
     {
 	fold = ajGraphicsSetCharscale(1.0);
-	ajGraphicsDrawposTextAtmid(xmid,1.0,
+	ajGraphicsDrawposTextAtmid(xmid,2.0,
                                    ajStrGetPtr(options));
 	ajGraphicsSetCharscale(fold);
     }
@@ -1267,8 +1276,10 @@ static void prettyplot_fillinboxes(ajint numseq, ajint length,
 	if(consensus && (numseq==seqend))
 	{
 	    res[0] = constr[k];
-	    ajGraphicsDrawposTextAtstart((float)(count+gapcount),
-                                         y-(yincr*((seqend-seqstart)+1)),res);
+
+	    /* start -> mid */
+            ajGraphicsDrawposTextAtmid((float) 0.5 + (float)(count+gapcount),
+                                       y-(yincr*((seqend-seqstart)+1)),res);
 	}
     }
 
@@ -1339,8 +1350,10 @@ static void prettyplot_fillinboxes(ajint numseq, ajint length,
 			    res[0] = seqcharptr[j][k];
 			else
 			    res[0] = '-';
-			ajGraphicsDrawposTextAtstart((float)(count+gapcount),
-                                                     y-(yincr*l),res);
+	    /* start -> mid */
+			ajGraphicsDrawposTextAtmid((float) 0.5 +
+                                                   (float) (count+gapcount),
+                                                   y-(yincr*l),res);
 		    }
 		}
 	    }
