@@ -296,7 +296,7 @@ static void showpep_FormatShow(EmbPShow ss,
 
     /* start token to parse format */
     tok = ajStrTokenNewC(format,  white);
-    while(ajStrTokenNextParseC(&tok, whiteplus, &code))
+    while(ajStrTokenNextParseC(tok, whiteplus, &code))
     {
 	ajStrFmtUpper(&code);
 
@@ -428,7 +428,7 @@ static AjBool showpep_MatchFeature(const AjPFeature gf, AjPFeature newgf,
     ** is this a child of a join() ?
     ** if it is a child, then we use the previous result of MatchPatternTags
     */
-    if(!ajFeatIsMultiple(gf) || !ajFeatIsChild(gf))
+    if(!ajFeatIsMultiple(gf))
 	*tagsmatch = showpep_MatchPatternTags(gf, newgf, tag, value,
 					      stricttags);
 
@@ -453,7 +453,7 @@ static AjBool showpep_MatchFeature(const AjPFeature gf, AjPFeature newgf,
         val = ajFalse;
         tokens = ajStrTokenNewC(type, " \t\n\r,;|");
 
-        while (ajStrTokenNextParse( &tokens, &key))
+        while (ajStrTokenNextParse(tokens, &key))
         {
             if (ajFeatTypeMatchWildS(gf, key))
             {
@@ -550,12 +550,12 @@ static AjBool showpep_MatchPatternTags(const AjPFeature gf,
 	    ** that match the criteria
 	    */
 	    if(stricttags)
-	    	ajFeatTagAdd(newgf, tagnam, tagval);
+	    	ajFeatTagAddSS(newgf, tagnam, tagval);
         }
 
         /* if not strict tags then need to see all the tags */
         if(!stricttags)
-            ajFeatTagAdd(newgf, tagnam, tagval);
+            ajFeatTagAddSS(newgf, tagnam, tagval);
     }
     ajListIterDel(&titer);
 
