@@ -103,16 +103,16 @@ int main(int argc, char **argv)
 	primdata->Oligob = NULL;
 
 	handle = ajStrTokenNewC(rdline, " \t");
-	ajStrTokenNextParse(&handle, &primdata->Name);
+	ajStrTokenNextParse(handle, &primdata->Name);
 
 	if(!(nprimers % 1000))
 	    ajDebug("Name [%d]: '%S'\n", nprimers, primdata->Name);
 
-	ajStrTokenNextParse(&handle, &primdata->Oligoa);
+	ajStrTokenNextParse(handle, &primdata->Oligoa);
 	ajStrFmtUpper(&primdata->Oligoa);
 	primdata->Prima = ajRegComp(primdata->Oligoa);
 
-	ajStrTokenNextParse(&handle, &primdata->Oligob);
+	ajStrTokenNextParse(handle, &primdata->Oligob);
 	ajStrFmtUpper(&primdata->Oligob);
 	primdata->Primb = ajRegComp(primdata->Oligob);
 	ajStrTokenDel(&handle);
@@ -137,7 +137,7 @@ int main(int argc, char **argv)
 	ajSeqstrReverse(&revstr);
 	ajDebug("Testing: %s\n", ajSeqGetNameC(seq));
 	ntests = 0;
-	ajListMap(primList, stssearch_primTest, NULL);
+	ajListMap(primList, &stssearch_primTest, NULL);
     }
 
     ajFileClose(&out);
@@ -148,7 +148,7 @@ int main(int argc, char **argv)
     ajStrDel(&revstr);
     ajStrDel(&seqstr);
     ajFileClose(&primfile);
-    ajListMap(primList, stssearch_primDel, NULL);
+    ajListMap(primList, &stssearch_primDel, NULL);
     ajListFree(&primList);
     ajStrDel(&rdline);
 
@@ -159,6 +159,8 @@ int main(int argc, char **argv)
 }
 
 
+
+
 /* @funcstatic stssearch_primDel **********************************************
 **
 ** Undocumented.
@@ -189,6 +191,8 @@ static void stssearch_primDel(void **x,  void *cl)
 }
 
 
+
+
 /* @funcstatic stssearch_primTest *********************************************
 **
 ** Undocumented.
