@@ -1,40 +1,66 @@
-/****************************************************************************
+/* @include embdmx ************************************************************
 **
-** @source embdmx.h
-** 
-** @source Algorithms for some of the DOMAINATRIX EMBASSY applications. 
-** For Scophit and Scopalign objects defined in ajxyz.h
+** Algorithms for some of the DOMAINATRIX EMBASSY applications. 
+** For use with the Scophit and Scopalign objects.  
 ** The functionality will eventually be subsumed by other AJAX and NUCLEUS 
 ** libraries. 
 ** 
-** @author: Copyright (C) 2004 Ranjeeva Ranasinghe (rranasin@hgmp.mrc.ac.uk)
-** @author: Copyright (C) 2004 Jon Ison (jison@hgmp.mrc.ac.uk) 
-** @version 1.0 
+** @author Copyright (C) 2004 Ranjeeva Ranasinghe (rranasin@hgmp.mrc.ac.uk)
+** @author Copyright (C) 2004 Jon Ison (jison@hgmp.mrc.ac.uk) 
+** @version $Revision: 1.20 $ 
+** @modified $Date: 2011/10/18 14:24:24 $ by $Author: rice $
 ** @@
 ** 
 ** This library is free software; you can redistribute it and/or
-** modify it under the terms of the GNU Library General Public
+** modify it under the terms of the GNU Lesser General Public
 ** License as published by the Free Software Foundation; either
-** version 2 of the License, or (at your option) any later version.
-** 
+** version 2.1 of the License, or (at your option) any later version.
+**
 ** This library is distributed in the hope that it will be useful,
 ** but WITHOUT ANY WARRANTY; without even the implied warranty of
 ** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-** Library General Public License for more details.
-** 
-** You should have received a copy of the GNU Library General Public
-** License along with this library; if not, write to the
-** Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-** Boston, MA  02111-1307, USA.
+** Lesser General Public License for more details.
+**
+** You should have received a copy of the GNU Lesser General Public
+** License along with this library; if not, write to the Free Software
+** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+** MA  02110-1301,  USA.
 ****************************************************************************/
 
-#ifdef __cplusplus
-extern "C"
-{
-#endif
+#ifndef EMBDMX_H
+#define EMBDMX_H
 
-#ifndef embdmx_h
-#define embdmx_h
+
+
+
+/* ========================================================================= */
+/* ============================= include files ============================= */
+/* ========================================================================= */
+
+#include "ajdefine.h"
+#include "ajlist.h"
+#include "ajfile.h"
+#include "ajseqdata.h"
+#include "ajdmx.h"
+#include "ajarr.h"
+#include "ajmatrices.h"
+#include "embsig.h"
+
+AJ_BEGIN_DECLS
+
+
+
+
+/* ========================================================================= */
+/* =============================== constants =============================== */
+/* ========================================================================= */
+
+
+
+
+/* ========================================================================= */
+/* ============================== public data ============================== */
+/* ========================================================================= */
 
 
 
@@ -61,9 +87,9 @@ typedef struct EmbSDmxNrseq {
 
 
 
-/*****************************************************************************/
-/* These functions are NOT YET DOCUMENTED in the appropriate data structures */
-/*****************************************************************************/
+/* ========================================================================= */
+/* =========================== public functions ============================ */
+/* ========================================================================= */
 
 
 
@@ -170,8 +196,6 @@ AjBool        embDmxSeqCompall(const AjPList input,
 ** End of prototype definitions
 */
 
-#endif
+AJ_END_DECLS
 
-#ifdef __cplusplus
-}
-#endif
+#endif  /* !EMBDMX_H */
