@@ -1,25 +1,45 @@
-/* @source embword.c
+/* @source embword ************************************************************
 **
 ** Wordmatch routines
 **
-** This program is free software; you can redistribute it and/or
-** modify it under the terms of the GNU General Public License
-** as published by the Free Software Foundation; either version 2
-** of the License, or (at your option) any later version.
+** @author Copyright (c) 1999 Gary Williams
+** @version $Revision: 1.65 $
+** @modified $Date: 2012/07/14 14:52:41 $ by $Author: rice $
+** @@
 **
-** This program is distributed in the hope that it will be useful,
+** This library is free software; you can redistribute it and/or
+** modify it under the terms of the GNU Lesser General Public
+** License as published by the Free Software Foundation; either
+** version 2.1 of the License, or (at your option) any later version.
+**
+** This library is distributed in the hope that it will be useful,
 ** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-** GNU General Public License for more details.
+** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+** Lesser General Public License for more details.
+**
+** You should have received a copy of the GNU Lesser General Public
+** License along with this library; if not, write to the Free Software
+** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+** MA  02110-1301,  USA.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 ******************************************************************************/
 
-#include "emboss.h"
+#include "ajlib.h"
+
+#include "embword.h"
+#include "ajassert.h"
+#include "ajseq.h"
+#include "ajfeat.h"
+#include "ajfile.h"
+#include "ajlist.h"
+#include "ajtable.h"
+#include "ajutil.h"
+
 #include <math.h>
 
+
+
+
 /*
 ** current wordlength - this is an easily accessible copy of the value
 ** in the first node of wordLengthList
@@ -63,9 +83,10 @@ static ajint    wordMatchCmpPos(const void* v1, const void* v2);
 static void     wordNewListTrace(ajint i, const AjPList newlist);
 static void     wordOrderPosMatchTable(AjPList unorderedList);
 
-static unsigned wordStrHash(const void *key, unsigned hashsize);
+static ajulong  wordStrHash(const void *key, ajulong hashsize);
 
-static void     wordVFree(void **key, void **count, void *cl);
+static void     wordVFreeLocs(void **value);
+static void     wordVFreeSeqlocs(void **value);
 
 static ajint    wordRabinKarpCmp(const void *trgseq, const void *qryseq);
 static ajulong  wordRabinKarpConstant(ajuint m);
@@ -80,6 +101,8 @@ static ajulong  wordRabinKarpConstant(ajuint m);
 ** @param [r] x [const void *] First word
 ** @param [r] y [const void *] Second word
 ** @return [ajint] difference
+**
+** @release 1.0.0
 ** @@
 ******************************************************************************/
 
@@ -96,14 +119,16 @@ static ajint wordCmpStr(const void *x, const void *y)
 ** Create hash value from key.
 **
 ** @param [r] key [const void *] key.
-** @param [r] hashsize [unsigned] Hash size
-** @return [unsigned] hash value
+** @param [r] hashsize [ajulong] Hash size
+** @return [ajulong] hash value
+**
+** @release 1.0.0
 ** @@
 ******************************************************************************/
 
-static unsigned wordStrHash(const void *key, unsigned hashsize)
+static ajulong wordStrHash(const void *key, ajulong hashsize)
 {
-    unsigned hashval;
+    ajulong hashval;
     const char *s;
 
     ajuint i;
@@ -126,6 +151,8 @@ static unsigned wordStrHash(const void *key, unsigned hashsize)
 ** @param [r] x [const void *] First word
 ** @param [r] y [const void *] Second word
 ** @return [ajint] count difference for words.
+**
+** @release 2.1.0
 ** @@
 ******************************************************************************/
 
@@ -156,6 +183,8 @@ static ajint wordCompare(const void *x, const void *y)
 **
 ** @param [r] wordlen [ajint] Word length
 ** @return [void]
+**
+** @release 1.0.0
 ** @@
 ******************************************************************************/
 
@@ -187,6 +216,8 @@ void embWordLength(ajint wordlen)
 ** If there is nothing else on the list, it frees the list.
 **
 ** @return [void]
+**
+** @release 1.0.0
 ** @@
 ******************************************************************************/
 
@@ -229,6 +260,8 @@ void embWordClear(void)
 **
 ** @param [r] table [const AjPTable] table to be printed
 ** @return [void]
+**
+** @release 1.0.0
 ** @@
 ******************************************************************************/
 
@@ -240,7 +273,7 @@ void embWordPrintTable(const AjPTable table)
 
     ajTableToarrayValues(table, &valarray);
 
-    qsort(valarray, ajTableGetLength(table), sizeof (*valarray), wordCompare);
+    qsort(valarray, (size_t) ajTableGetLength(table), sizeof (*valarray), wordCompare);
 
     for(i = 0; valarray[i]; i++)
     {
@@ -264,6 +297,8 @@ void embWordPrintTable(const AjPTable table)
 ** @param [r] mincount [ajint] Minimum frequency to report
 ** @param [u] outf [AjPFile] Output file.
 ** @return [void]
+**
+** @release 4.0.0
 ** @@
 ******************************************************************************/
 
@@ -275,7 +310,7 @@ void embWordPrintTableFI(const AjPTable table, ajint mincount, AjPFile outf)
 
     if(!ajTableGetLength(table)) return;
 
-    i = ajTableToarrayValues(table, &valarray);
+    i = (ajuint) ajTableToarrayValues(table, &valarray);
 
     ajDebug("embWordPrintTableFI size %d mincount:%d\n", i, mincount);
 
@@ -286,7 +321,7 @@ void embWordPrintTableFI(const AjPTable table, ajint mincount, AjPFile outf)
 		i, wordLength, ajnew->fword,ajnew->count);
     }
 
-    qsort(valarray, ajTableGetLength(table), sizeof (*valarray), wordCompare);
+    qsort(valarray, (size_t) ajTableGetLength(table), sizeof (*valarray), wordCompare);
 
     for(i = 0; valarray[i]; i++)
     {
@@ -316,6 +351,8 @@ void embWordPrintTableFI(const AjPTable table, ajint mincount, AjPFile outf)
 ** @param [r] table [const AjPTable] table to be printed
 ** @param [u] outf [AjPFile] Output file.
 ** @return [void]
+**
+** @release 1.0.0
 ** @@
 ******************************************************************************/
 
@@ -329,58 +366,22 @@ void embWordPrintTableF(const AjPTable table, AjPFile outf)
 
 
 
-/* @funcstatic wordPositionListDelete *****************************************
-**
-** deletes entries in a list of positions.
-**
-** @param [d] x [void**] Data values as void**
-** @param [r] cl [void*] Ignored user data, usually NULL.
-** @return [void]
-** @@
-******************************************************************************/
-
-static void wordPositionListDelete(void **x,void *cl)
-{
-    ajint *p;
-
-    p = (ajint *)*x;
-
-    AJFREE(p);
-
-    if(!cl)
-        return;
-
-    return;
-}
-
-
-
-
-/* @funcstatic wordVFreeSeqLocs ***********************************************
+/* @funcstatic wordVFreeLocs **************************************************
 **
 ** Free the elements in a EmbPWord locations table.
 **
-** @param [r] key [void**] key for a table item
-** @param [d] value [void**] Data values as void**
-** @param [r] cl [void*] Ignored user data, usually NULL.
+** @param [d] value [void**] Data value for a table item
 ** @return [void]
+**
+** @release 6.4.0
 ** @@
 ******************************************************************************/
 
-static void wordVFreeSeqLocs(void **key, void **value, void *cl)
+static void wordVFreeLocs(void **value)
 {
-    AjPStr mykey;
+    AjPTable table = ((EmbPWord)*value)->seqlocs;
 
-    (void) cl;                  /* make it used */
-
-    mykey = (AjPStr) *key;
-    ajStrDel(&mykey);
-
-    /* free the elements in the list of the positions */
-    ajListMap(((EmbPWordSeqLocs)*value)->locs,wordPositionListDelete, NULL);
-
-    /* free the list structure for the positions. */
-    ajListFree(&((EmbPWordSeqLocs)*value)->locs);
+    ajTableDelValdel(&table, &wordVFreeSeqlocs);
 
     /* free the locations structure */
     AJFREE(*value);
@@ -391,34 +392,26 @@ static void wordVFreeSeqLocs(void **key, void **value, void *cl)
 
 
 
-/* @funcstatic wordVFree ******************************************************
+/* @funcstatic wordVFreeSeqlocs ***********************************************
 **
-** free the elements in a list of positions
+** Free the elements in a EmbPWord sequence locations list.
 **
-** @param [r] key [void**] key for a table item
-** @param [d] count [void**] Data values as void**
-** @param [r] cl [void*] Ignored user data, usually NULL.
+** @param [d] value [void**] Data values as void**
 ** @return [void]
+**
+** @release 6.4.0
 ** @@
 ******************************************************************************/
 
-static void wordVFree(void **key, void **count, void *cl)
+static void wordVFreeSeqlocs(void **value)
 {
-    char* ckey;
+    AjPList list = ((EmbPWordSeqLocs)*value)->locs;
 
-    ckey = (char*) *key;
-    ajCharDel(&ckey);
+    /* free the elements in the list of the positions */
+    ajListFreeData(&list);
 
-
-    ajTableMapDel(((EmbPWord)*count)->seqlocs, wordVFreeSeqLocs, NULL);
-
-    ajTableFree(&((EmbPWord)*count)->seqlocs);
-
-    /* free the word structure */
-    AJFREE(*count);
-
-    if(!cl)
-        return;
+    /* free the locations structure */
+    AJFREE(*value);
 
     return;
 }
@@ -432,14 +425,14 @@ static void wordVFree(void **key, void **count, void *cl)
 **
 ** @param [d] table [AjPTable*] table to be deleted
 ** @return [void]
+**
+** @release 1.0.0
 ** @@
 ******************************************************************************/
 
 void embWordFreeTable(AjPTable *table)
 {
-    ajTableMapDel(*table, wordVFree, NULL);
-    ajTableFree(table);
-    table = 0;
+    ajTableDel(table);
 
     return;
 }
@@ -454,6 +447,8 @@ void embWordFreeTable(AjPTable *table)
 ** @param [d] x [void**] Data values as void**
 ** @param [r] cl [void*] Ignored user data, usually NULL.
 ** @return [void]
+**
+** @release 2.1.0
 ** @@
 ******************************************************************************/
 
@@ -480,6 +475,8 @@ static void wordMatchListDelete(void **x,void *cl)
 **
 ** @param [u] plist [AjPList*] list to be deleted.
 ** @return [void]
+**
+** @release 1.0.0
 ** @@
 ******************************************************************************/
 
@@ -488,7 +485,7 @@ void embWordMatchListDelete(AjPList* plist)
     if(!*plist)
 	return;
 
-    ajListMap(*plist,wordMatchListDelete, NULL);
+    ajListMap(*plist, &wordMatchListDelete, NULL);
     ajListFree(plist);
 
     return;
@@ -504,6 +501,8 @@ void embWordMatchListDelete(AjPList* plist)
 ** @param [r] x [void*] List item (EmbPWordMatch*)
 ** @param [r] cl [void*] Output file AjPFile
 ** @return [void]
+**
+** @release 2.1.0
 ** @@
 ******************************************************************************/
 
@@ -533,12 +532,14 @@ static void wordMatchListPrint(void *x,void *cl)
 ** @param [u] file [AjPFile] Output file
 ** @param [r] list [const AjPList] list to be printed.
 ** @return [void]
+**
+** @release 1.0.0
 ** @@
 ******************************************************************************/
 
 void embWordMatchListPrint(AjPFile file, const AjPList list)
 {
-    ajListMapread(list,wordMatchListPrint, file);
+    ajListMapread(list, &wordMatchListPrint, file);
 
     return;
 }
@@ -556,6 +557,8 @@ void embWordMatchListPrint(AjPFile file, const AjPList list)
 ** @param [r] seq1 [const AjPSeq] sequence
 ** @param [r] seq2 [const AjPSeq] second sequence
 ** @return [void]
+**
+** @release 1.0.0
 ** @@
 ******************************************************************************/
 
@@ -621,6 +624,8 @@ void embWordMatchListConvToFeat(const AjPList list,
 ** @param [u] table [AjPTable*] table to be created or updated.
 ** @param [r] seq [const AjPSeq] Sequence to be "worded"
 ** @return [AjBool] ajTrue if successful
+**
+** @release 1.0.0
 ** @@
 ******************************************************************************/
 
@@ -662,7 +667,8 @@ AjBool embWordGetTable(AjPTable *table, const AjPSeq seq)
     if(!*table)
     {
 	*table = ajTableNewFunctionLen(ajSeqGetLen(seq),
-				       wordCmpStr, wordStrHash);
+				       &wordCmpStr, &wordStrHash,
+                                       &ajMemFree, &wordVFreeLocs);
 	ajDebug("make new table\n");
     }
 
@@ -723,7 +729,7 @@ AjBool embWordGetTable(AjPTable *table, const AjPSeq seq)
 	    continue;
 	}
 
-	rec = (EmbPWord) ajTableFetch(*table, startptr);
+	rec = (EmbPWord) ajTableFetchmodV(*table, startptr);
 
 	/* does it exist already */
 	if(rec)
@@ -738,14 +744,14 @@ AjBool embWordGetTable(AjPTable *table, const AjPSeq seq)
 	    rec->count = 1;
 	    key = ajCharNewResLenC(startptr, wordsize, wordLength);
 	    rec->fword = key;
-	    rec->seqlocs = ajTablestrNew();
+	    rec->seqlocs = ajTablestrNew(1000);
 	    ajTablePut(*table, key, rec);
 	}
 
 	AJNEW0(k);
 	*k = i;
 	seqname = ajSeqGetNameS(seq);
-	seqlocs = (EmbPWordSeqLocs) ajTableFetch(rec->seqlocs, seqname);
+	seqlocs = (EmbPWordSeqLocs) ajTableFetchmodS(rec->seqlocs, seqname);
 
 	if (seqlocs == NULL)
 	{
@@ -762,7 +768,7 @@ AjBool embWordGetTable(AjPTable *table, const AjPSeq seq)
 
     }
 
-    ajDebug("table done, size %d\n", ajTableGetLength(*table));
+    ajDebug("table done, size %Lu\n", ajTableGetLength(*table));
 
     return ajTrue;
 }
@@ -776,13 +782,15 @@ AjBool embWordGetTable(AjPTable *table, const AjPSeq seq)
 **
 ** @param [u] unorderedList [AjPList] Unsorted list
 ** @return [void]
+**
+** @release 2.1.0
 ** @@
 ******************************************************************************/
 
 static void wordOrderMatchTable(AjPList unorderedList)
 {
     ajDebug("wordOrderMatchTable size %d\n", ajListGetLength(unorderedList));
-    ajListSort(unorderedList, wordMatchCmp);
+    ajListSort(unorderedList, &wordMatchCmp);
 
     return;
 }
@@ -801,6 +809,8 @@ static void wordOrderMatchTable(AjPList unorderedList)
 ** @param [r] v2 [const void*] Comparison word
 ** @return [ajint] Comparison value. 0 if equal, -1 if first is lower,
 **               +1 if first is higher.
+**
+** @release 1.0.0
 ** @@
 ******************************************************************************/
 
@@ -858,12 +868,14 @@ static ajint wordMatchCmp(const void* v1, const void* v2)
 **
 ** @param [u] unorderedList [AjPList] Unsorted list
 ** @return [void]
+**
+** @release 2.1.0
 ** @@
 ******************************************************************************/
 
 static void wordOrderPosMatchTable(AjPList unorderedList)
 {
-    ajListSort(unorderedList, wordMatchCmpPos);
+    ajListSort(unorderedList, &wordMatchCmpPos);
 
     return;
 }
@@ -882,6 +894,8 @@ static void wordOrderPosMatchTable(AjPList unorderedList)
 ** @param [r] v2 [const void*] Comparison word
 ** @return [ajint] Comparison value. 0 if equal, -1 if first is lower,
 **               +1 if first is higher.
+**
+** @release 1.0.0
 ** @@
 ******************************************************************************/
 
@@ -942,6 +956,8 @@ static ajint wordMatchCmpPos(const void* v1, const void* v2)
 ** @param [r] orderit [ajint] 1 to sort results at end, else 0.
 ** @return [AjPList] List of matches.
 ** @error NULL table was not built due to an error.
+**
+** @release 1.0.0
 ** @@
 ******************************************************************************/
 
@@ -991,7 +1007,7 @@ AjPList embWordBuildMatchTable(const AjPTable seq1MatchTable,
 
     while(i < (ilast+1))
     {
-	if((wordmatch = ajTableFetch(seq1MatchTable, startptr)))
+	if((wordmatch = ajTableFetchmodV(seq1MatchTable, startptr)))
 	{
 	    /* match found so create EmbSWordMatch structure and fill it
 	    ** in. Then set next pos accordingly
@@ -1125,31 +1141,6 @@ AjPList embWordBuildMatchTable(const AjPTable seq1MatchTable,
 
 
 
-/* @obsolete embWordMatchListAppend
-** @remove use embWordMatchNew followed by a list append call
-*/
-__deprecated EmbPWordMatch embWordMatchListAppend(AjPList hitlist,
-                                                  const AjPSeq seq,
-                                                  const ajuint seq1start,
-                                                  ajuint seq2start,
-                                                  ajint length)
-{
-    EmbPWordMatch match;
-    AJNEW0(match);
-    match->sequence  = seq;
-    match->seq1start = seq1start;
-    match->seq2start = seq2start;
-    match->length = length;
-    ajDebug("new word match start1: %d start2: %d len: %d\n",
-            match->seq1start, match->seq2start,
-            match->length);
-    ajListPushAppend(hitlist, match);
-    return match;
-}
-
-
-
-
 /* @func embWordMatchNew ******************************************************
 **
 ** Creates and initialises a word match object
@@ -1159,6 +1150,8 @@ __deprecated EmbPWordMatch embWordMatchListAppend(AjPList hitlist,
 ** @param [r] seq2start [ajuint] Start position in query sequence
 ** @param [r] length [ajint] length of the word match
 ** @return [EmbPWordMatch] New word match object.
+**
+** @release 6.3.0
 ** @@
 ******************************************************************************/
 
@@ -1191,6 +1184,8 @@ EmbPWordMatch embWordMatchNew(const AjPSeq seq, ajuint seq1start,
 ** @param [r] i [ajint] Offset
 ** @param [r] newlist [const AjPList] word list.
 ** @return [void]
+**
+** @release 1.0.0
 ** @@
 ******************************************************************************/
 
@@ -1225,6 +1220,8 @@ static void wordNewListTrace(ajint i, const AjPList newlist)
 **
 ** @param [r] curlist [const AjPList] word list.
 ** @return [void]
+**
+** @release 1.0.0
 ** @@
 ******************************************************************************/
 
@@ -1265,6 +1262,8 @@ static void wordCurListTrace(const AjPList curlist)
 **
 ** @param [r] curiter [const AjIList] List iterator for the current word list
 ** @return [void]
+**
+** @release 1.0.0
 ** @@
 ******************************************************************************/
 
@@ -1343,6 +1342,8 @@ static void wordCurIterTrace(const AjIList curiter)
 ** @param [r] deady2 [ajint] y position of end of live zone 2
 ** @param [r] minlength [ajint] minimum length of match
 ** @return [ajint] 0=in live zone, 1=in dead zone, 2=truncated
+**
+** @release 2.1.0
 ** @@
 ******************************************************************************/
 
@@ -1445,6 +1446,8 @@ static ajint wordDeadZone(EmbPWordMatch match,
 ** @param [u] matchlist [AjPList] list of matches to reduce to
 **                                non-overlapping set
 ** @return [void]
+**
+** @release 2.0.0
 ** @@
 ******************************************************************************/
 
@@ -1549,6 +1552,8 @@ void embWordMatchMin(AjPList matchlist)
 **
 ** @param [r] matchlist [const AjPList] list of matches
 ** @return [EmbPWordMatch] maximum match
+**
+** @release 6.3.0
 ** @@
 ******************************************************************************/
 
@@ -1592,13 +1597,15 @@ EmbPWordMatch embWordMatchFirstMax(const AjPList matchlist)
 
 
 
-/* @funcstatic wordRabinKarpConstant *****************************************
+/* @funcstatic wordRabinKarpConstant ******************************************
 **
 ** Returns a value that helps recalculating consecutive hash values
 ** with less computation during Rabin-Karp search.
 **
 ** @param [r] m [ajuint] word length
 ** @return [ajulong] radix^(m-1) % modulus
+**
+** @release 6.3.0
 ** @@
 ******************************************************************************/
 
@@ -1618,7 +1625,7 @@ static ajulong wordRabinKarpConstant(ajuint m)
 
 
 
-/* @funcstatic wordRabinKarpCmp *********************************************
+/* @funcstatic wordRabinKarpCmp ***********************************************
 **
 ** Comparison function for EmbPWordRK objects, based on their hash values
 **
@@ -1626,6 +1633,8 @@ static ajulong wordRabinKarpConstant(ajuint m)
 ** @param [r] qryseq [const void *] Second EmbPWordRK object
 **
 ** @return [ajint] difference of hash values
+**
+** @release 6.3.0
 ******************************************************************************/
 
 static ajint wordRabinKarpCmp(const void *trgseq, const void *qryseq)
@@ -1648,30 +1657,32 @@ static ajint wordRabinKarpCmp(const void *trgseq, const void *qryseq)
 
 
 
-/* @func embWordRabinKarpInit ************************************************
+/* @func embWordRabinKarpInit *************************************************
 **
 ** Scans word/pattern table and repackages the words in EmbPWordRK
 ** objects to improve access efficiency by Rabin-Karp search.
 ** Computes hash values for each word/pattern.
 **
 ** @param [r] table [const AjPTable] Table of patterns
-** @param [u] newwords [EmbPWordRK**] Extended patterns to be used
-**                                    by Rabin-Karp search
+** @param [u] ewords [EmbPWordRK**] Extended word objects to be used
+**                                  in Rabin-Karp search
 ** @param [r] wordlen [ajuint] Length of words/patterns, kmer size
 ** @param [r] seqset [const AjPSeqset] Sequence set, input patterns
 **                                     were derived from
 ** @return [ajuint] number of words
+**
+** @release 6.3.0
 ** @@
 ******************************************************************************/
 
-ajuint embWordRabinKarpInit(const AjPTable table, EmbPWordRK** newwords,
+ajuint embWordRabinKarpInit(const AjPTable table, EmbPWordRK** ewords,
                             ajuint wordlen, const AjPSeqset seqset)
 {
     ajuint i;
     ajuint j;
     ajuint k;
     ajuint l;
-    EmbPWord* embwords = NULL;
+    EmbPWord* words = NULL;
     const EmbPWord embword = NULL;
     ajulong patternHash;
     EmbPWordRK newword = NULL;
@@ -1685,13 +1696,13 @@ ajuint embWordRabinKarpInit(const AjPTable table, EmbPWordRK** newwords,
     ajuint pos;
     
     nseqs = ajSeqsetGetSize(seqset);
-    nwords = ajTableToarrayValues(table, (void***)&embwords);
-    AJCNEW(*newwords, nwords);
+    nwords = (ajuint) ajTableToarrayValues(table, (void***)&words);
+    AJCNEW(*ewords, nwords);
 
     for(i=0; i<nwords; i++)
     {
         seqlocs=NULL;
-        embword = embwords[i];
+        embword = words[i];
         word = embword->fword;
 
         AJNEW0(newword);
@@ -1702,9 +1713,9 @@ ajuint embWordRabinKarpInit(const AjPTable table, EmbPWordRK** newwords,
          *       as we do in the search function */
         for(j=0; j<wordlen; j++)
             patternHash = (RK_RADIX * patternHash +
-        	    toupper(word[j]))% RK_MODULUS;
+			   toupper((int)word[j]))% RK_MODULUS;
 
-        nseqlocs = ajTableToarrayValues(embword->seqlocs, (void***)&seqlocs);
+        nseqlocs = (ajuint) ajTableToarrayValues(embword->seqlocs, (void***)&seqlocs);
         newword->nseqs = nseqlocs;
         newword->hash  = patternHash;
         newword->word = embword;
@@ -1732,7 +1743,7 @@ ajuint embWordRabinKarpInit(const AjPTable table, EmbPWordRK** newwords,
 
             iterp = ajListIterNewread(seqlocs[j]->locs);
             k = 0;
-            newword->nnseqlocs[j]= ajListGetLength(seqlocs[j]->locs);
+            newword->nnseqlocs[j] = (ajuint) ajListGetLength(seqlocs[j]->locs);
             AJCNEW(newword->locs[j],newword->nnseqlocs[j]);
 
             while(!ajListIterDone(iterp))
@@ -1746,13 +1757,13 @@ ajuint embWordRabinKarpInit(const AjPTable table, EmbPWordRK** newwords,
 
         AJFREE(seqlocs);
 
-        (*newwords)[i] = newword;
+        (*ewords)[i] = newword;
 
     }
 
-    AJFREE(embwords);
+    AJFREE(words);
 
-    qsort(*newwords, nwords, sizeof(EmbPWordRK), wordRabinKarpCmp);
+    qsort(*ewords, nwords, sizeof(EmbPWordRK), wordRabinKarpCmp);
 
     return nwords;
 }
@@ -1767,7 +1778,7 @@ ajuint embWordRabinKarpInit(const AjPTable table, EmbPWordRK** newwords,
 ** @param [r] sseq [const AjPStr] Sequence to be scanned for multiple patterns
 ** @param [r] seqset [const AjPSeqset] Sequence-set,
 **                                     where search patterns coming from
-** @param [r] patterns [const EmbPWordRK*] Patterns to be searched
+** @param [r] patterns [EmbPWordRK const *] Patterns to be searched
 ** @param [r] plen [ajuint] Length of patterns
 ** @param [r] npatterns [ajuint] Number of patterns
 ** @param [u] matchlist [AjPList*] List of matches for each sequence
@@ -1777,12 +1788,14 @@ ajuint embWordRabinKarpInit(const AjPTable table, EmbPWordRK** newwords,
 ** @param [r] checkmode [AjBool] If true, not writing features or alignments
 **                               but running to produce match statistics only
 ** @return [ajuint] total number of matches
+**
+** @release 6.3.0
 ** @@
 ******************************************************************************/
 
 ajuint embWordRabinKarpSearch(const AjPStr sseq,
                               const AjPSeqset seqset,
-                              const EmbPWordRK* patterns,
+                              EmbPWordRK const * patterns,
                               ajuint plen, ajuint npatterns,
                               AjPList* matchlist,
                               ajuint* lastlocation, AjBool checkmode)
@@ -1816,7 +1829,7 @@ ajuint embWordRabinKarpSearch(const AjPStr sseq,
 
     for(i=0; i<plen; i++)
         textHash = (ajulong)(RK_RADIX * textHash   +
-        	toupper(text[i])) % RK_MODULUS;
+			     toupper((int)text[i])) % RK_MODULUS;
 
     /* Scan the input sequence sseq for all patterns */
     for (i=plen; i<=tlen; i++)
@@ -1851,8 +1864,8 @@ ajuint embWordRabinKarpSearch(const AjPStr sseq,
                          */
                         while(matchlen<plen)
                         {
-                            if(toupper(seq_[pos+matchlen]) !=
-                        	    toupper(text[ii++]))
+			  if(toupper((int)seq_[pos+matchlen]) !=
+			     toupper((int)text[ii++]))
                             {
                                 AJCNEW0(tmp,plen+1);
                                 tmp[plen] = '\0';
@@ -1875,8 +1888,8 @@ ajuint embWordRabinKarpSearch(const AjPStr sseq,
                         /* this is where we extend matches */
                         while(ii<tlen  && pos+matchlen<ajSeqGetLen(seq))
                         {
-                            if(toupper(seq_[pos+matchlen]) !=
-                        	    toupper(text[ii++]))
+			  if(toupper((int)seq_[pos+matchlen]) !=
+			     toupper((int)text[ii++]))
                                 break;
                             else
                                 ++matchlen;
@@ -1906,8 +1919,8 @@ ajuint embWordRabinKarpSearch(const AjPStr sseq,
             }
         }
 
-        textHash = ((textHash + toupper(text[i-plen]) * (RK_MODULUS-rm))
-        	* RK_RADIX + toupper(text[i])) % RK_MODULUS;
+        textHash = ((textHash + toupper((int)text[i-plen]) * (RK_MODULUS-rm))
+		    * RK_RADIX + toupper((int)text[i])) % RK_MODULUS;
     }
 
     AJFREE(cursor);
@@ -1930,6 +1943,8 @@ ajuint embWordRabinKarpSearch(const AjPStr sseq,
 ** @param [w] seq [const AjPSeq*] Pointer to sequence
 ** @return [AjBool] ajFalse if the iterator was exhausted
 **
+**
+** @release 2.4.0
 ******************************************************************************/
 
 AjBool embWordMatchIter(AjIList iter, ajint* start1, ajint* start2,
@@ -1961,6 +1976,8 @@ AjBool embWordMatchIter(AjIList iter, ajint* start1, ajint* start2,
 ** @param [u] iter [AjIList] List iterator.
 ** @param [r] x [void*] Data item to insert.
 ** @return [void]
+**
+** @release 2.1.0
 ** @@
 ******************************************************************************/
 
@@ -2008,6 +2025,8 @@ static void wordListInsertOld(AjIList iter, void* x)
 ** @param [u] pnode [AjPListNode*] Current node.
 ** @param [r] x [void*] Data item to insert.
 ** @return [void]
+**
+** @release 2.1.0
 ** @@
 ******************************************************************************/
 
@@ -2033,6 +2052,8 @@ static void wordListInsertNodeOld(AjPListNode* pnode, void* x)
 ** Unused functions. Here to keep compiler warnings away
 **
 ** @return [void]
+**
+** @release 2.0.0
 ******************************************************************************/
 
 void embWordUnused(void)
@@ -2053,6 +2074,8 @@ void embWordUnused(void)
 ** Cleanup word matching indexing internals on exit
 **
 ** @return [void]
+**
+** @release 4.0.0
 ******************************************************************************/
 
 void embWordExit(void)
@@ -2062,3 +2085,36 @@ void embWordExit(void)
 
     return;
 }
+
+
+
+
+#ifdef AJ_COMPILE_DEPRECATED_BOOK
+#endif
+
+
+
+
+#ifdef AJ_COMPILE_DEPRECATED
+/* @obsolete embWordMatchListAppend
+** @remove use embWordMatchNew followed by a list append call
+*/
+__deprecated EmbPWordMatch embWordMatchListAppend(AjPList hitlist,
+                                                  const AjPSeq seq,
+                                                  const ajuint seq1start,
+                                                  ajuint seq2start,
+                                                  ajint length)
+{
+    EmbPWordMatch match;
+    AJNEW0(match);
+    match->sequence  = seq;
+    match->seq1start = seq1start;
+    match->seq2start = seq2start;
+    match->length = length;
+    ajDebug("new word match start1: %d start2: %d len: %d\n",
+            match->seq1start, match->seq2start,
+            match->length);
+    ajListPushAppend(hitlist, match);
+    return match;
+}
+#endif
